/*
+-----------------------------------------------------------------+
| NAME:                                                           |
| swa42_migration.sql                                             |
|                                                                 |
| TYPE:                                                           |
| SQL code                                                        |
|                                                                 |
| DESCRIPTION:                                                    |
| This script contains SQL statements for updating SAS Warranty   |
| Analysis 4.2 tables when there is a migration from an earlier   |
| version of SWA.                                                 |
|                                                                 |
|                                                                 |
| SAS VERSION:                                                    |
| This software unit was developed for version 9.2                |
|                                                                 |
| HISTORY:                                                        |
| sasezw    29Jan2009   Initial coding.                           |
| gunedu    11Mar2009   Removed proc sql call and hard-coded      |
|                       USERDL libref                             |
| gunedu    12Mar2009   Added changes made to PARMSL tables       |
| gunedu    17Mar2009   Added fix for S0568112                    |
| sasezw    20Mar2009   added row to parmsl.modulesdefinition table|
| sasezw    23Mar2009   changed format NLDATM. to NLDATE. for     |
|                       fs_last_access_date                       |
| gunedu    24Mar2009   Added fix for S0554898                    |
| gunedu    25Mar2009   Added fix for S0558266                    |
| gunedu    25Mar2009   Added fix for S0558311                    |
| gunedu    01Apr2009   Added additional fix for S0558266         |
| gunedu    10Apr2009   Added EIDRILLTO to analysisoptions        |
| gunedu    13Apr2009   Added subscription and subscription_details|
|                       tables to userdl                          |
| gunedu    15Apr2009   Added changes to PARMSL.SWADATATYPES to   |
|                       fix S0483159                              |
| gunedu    21Apr2009   Added a missing & to userdlLibRef, deleted|
|                       three unused PARMSL tables and changed    |
|                       constraints on ANALYSISTYPES_BASE table   |
| gunedu    22Apr2009   Added fix for S0574751                    |
| gunedu    01May2009   Corrected hardcoded PARMSL libref         |
| atbroo    02May2009   Updated values for DISPLAYGRID            |
| sindok    04May2009   TOCREPORTVARIABLEs update for Gaps in Line|
| atbroo    04May2009   Updated values for NOSLIDERVARS           |
| gunedu    21May2009   Added fix for S0558266                    |
| gunedu    02Jun2009   Added fix for S0562733                    |
| atbroo    04Jun2009   Updated values for NOSLIDERVARS           |
| gunedu    16Jun2009   Added fix for S0555765                    |
| atbroo    17Jun2009   Updated Reliab Conf Limits                |
| atbroo    24Jun2009   Updated Pareto Min Sample Size            |
| atbroo    24Jun2009   Removed NewModel related metadata         |
|                       migration will not include NewModel setup |
| atbroo    24Jun2009   Fixed wrong field from previous update    |
| gunedu    06Jul2009   Added fixes for S0502827 and S0581584     |
| gunedu    10JUl2009   Added fixes for S0513512 and S0583065     |
| gunedu    14Jul2009   Added fix for S0594121                    |
| gunedu    16Jul2009   Added fix for S0587476                    |
| gunedu    17Jul2009   Addef fix for S0509898                    |
| gunedu    24Jul2009   Deleted swasrv user from parmsl.userattributes|
|                       when migrating to SWA 4.2                 |
| gunedu    24Jul2009   Added fix for S0590477                    |
| gunedu    29Jul2009   Added fix for S0597102                    |
| gunedu    03Aug2009   Reversed 29Jul changes and added a new fix|
|                       for S0597102                              |
| gunedu    06Aug2009   Added fix for S0599571                    |
| gunedu    13Aug2009   Added fix for S0601140                    |
| gunedu    19Jul2009   Added fix for S0591266                    |
| gunedu    03Sep2009   Fixed S0606935                            |
| max       01Mar2010   Add additional entries to                 |
|                       parms.modulesdefinition S0648245.         |
| max       16Mar2010   Set regular expression to prohibit comma  |
|                       entry in EI claims where clause fields,   |
|                       etc. S0643504                             |
| gunedu    02Apr2010   Fixed S0635341                            |
| sasjal    03Sep2010   For defect A0679311:                      |
|                       * inserted row into PARMSL.analysismacvars|
|                       * inserted row into PARMSL.eiautoparms    |
| sasjal    10Sep2010   Changed date format for V175, V176, V177  |
|                       to NLDATE. format.                        |
| sasjal    10Sep2010   Migration changes for S0682090, affecting |
|                       PARMSL.dataselectionattributes_base,      |
|                       PARMSL.dsattrs_format_nls, and            |
|                       PARMSL.dsattrs_label_nls                  |
| max       17Dec2010   S0725910                                  |
| max       27Dec2011   S0777005                                  |
| sascis    23Jan2012   S0826550: personOMRname                   |
+-----------------------------------------------------------------+
+-----------------------------------------------------------------+
| Copyright (c) 2012 by SAS Institute Inc., Cary, NC 27513 USA    |
| ---All Rights Reserved.                                         |
+-----------------------------------------------------------------+
*/


/* -------------------------------------------------------------- */
/* Updates to Analysis Macro Vars Table                           */
/* - Adding rows                                                  */
/* - Updating NOSLIDERVARS                                        */
/* -------------------------------------------------------------- */

   insert into &parmslLibRef..ANALYSISMACVARS
      (ANALYSISTYPE, MACROVAR, MACROSTMT)
      values ('COMMON','ANNUALIZE_EXTRAPOLATED',"&annualized_extrapolated")
      values ('COMMON','ANNUAL_COUNT',"&annualize_min_count")
      values ('EIANALYTIC','prodDate','PRODUCTION_DT')
      values ('EIANALYTIC','saleDate','IN_SERVICE_DT')
      values ('EIANALYTIC','claimdate','CLAIM_REPAIR_START_DT_SK')
      values ('EITHRESHOLD','maxNumBars','25')
      values ('MULTIVARIATE','minnumobs','25')
      values ('TEXTANALYSIS', 'numDescTermsForDisplay', '5')
   ;
   update &parmslLibRef..ANALYSISMACVARS set
     MACROSTMT = strip(MACROSTMT) !! ' FILLEDINDX UNFILLEDINDX VAR2MATURE VAR2IMMATURE VAR3MATURE VAR3IMMATURE VAR4MATURE VAR4IMMATURE VAR5MATURE VAR5IMMATURE'
       where upcase(MACROVAR)='NOSLIDERVARS'
       and (ANALYSISTYPE='COMMON' or ANALYSISTYPE='TREND' or ANALYSISTYPE='TRENDEXP' or ANALYSISTYPE='FORECASTING' or ANALYSISTYPE='EXPOSURE')
   ;
   update &parmslLibRef..ANALYSISMACVARS set
     MACROSTMT = strip(MACROSTMT) !! ' VAR6MATURE VAR6IMMATURE VAR7MATURE VAR7IMMATURE VAR8MATURE VAR8IMMATURE VAR9MATURE VAR9IMMATURE VAR10MATURE VAR10IMMATURE'
       where upcase(MACROVAR)='NOSLIDERVARS'
       and (ANALYSISTYPE='COMMON' or ANALYSISTYPE='TREND' or ANALYSISTYPE='TRENDEXP' or ANALYSISTYPE='FORECASTING' or ANALYSISTYPE='EXPOSURE')
   ;
   update &parmslLibRef..ANALYSISMACVARS set
     MACROSTMT = strip(MACROSTMT) !! ' LIFELOWER LIFEUPPER PROB LOWER UPPER STDERR X Y CDFY'
       where upcase(MACROVAR)='NOSLIDERVARS'
       and (ANALYSISTYPE='COMMON' or ANALYSISTYPE='RELIABILITY')
   ;

     update &parmslLibRef..analysismacvars
      set macrostmt='BUILD_PERIOD'
      where analysistype='EIANALYTIC' and
       upcase(macrovar)='PPERIODVAR'
      ;
      
      update &parmslLibRef..analysismacvars
      set macrostmt='INSERVICE_PERIOD'
      where analysistype='EIANALYTIC' and
       upcase(macrovar)='SPERIODVARCMONTH'
      ;
      
      insert into &parmslLibRef..analysismacvars
           set analysistype='EIANALYTIC',macrovar='maxfperiod',macrostmt=''
      ;      
      
/* -------------------------------------------------------------- */
/* Updates to MODULESDEFINITION Table                             */
/* - Adding rows                                                  */
/* -------------------------------------------------------------- */

   insert into &parmslLibRef..MODULESDEFINITION
      (MODULENAME,MODULECONTROLLER)
      values ('UTIL_GETFILTERCOUNT','%util_getFilterCount')
      values ('UTIL_DELETEPENDINGDELETETABLES','%util_deletePendingDeleteTables')

      values ('MYEMERGINGISSUEALERTS','%util_myemergingissuesalerts')
      values ('UTIL_EIDRILLTOA_SETDSLINKS','%util_eidrilltoa_setdslinks')
      values ('UTIL_EIDRILLTO_SETDSLINKS','%util_eidrillto_setdslinks')
   ;


/* -------------------------------------------------------------- */
/* Updates to ANLFORMATLABEL_xxxx Tables                          */
/* - Adding new labels                                            */
/* - Deleting rows that have been moved to VARIABLES table        */
/* -------------------------------------------------------------- */

      select KEY into :key 
        from &parmslLibRef..ANLFORMATLABEL_BASE
        where VARNAME = 'CUMTOTALCLAIMRATE' 
      ;

      update &parmslLibRef..ANLFORMATLABEL_LABEL_NLS set
     TEXT="&a19" where KEY = "&KEY"
      ;
 
      select KEY into :key 
        from &parmslLibRef..ANLFORMATLABEL_BASE
        where VARNAME = 'EXPT' 
      ;

      update &parmslLibRef..ANLFORMATLABEL_LABEL_NLS set
     TEXT="&a19" where KEY = "&KEY"
      ;

     insert into &parmslLibRef..ANLFORMATLABEL_BASE
      (KEY,VARNAME,OTHERCRITERIAVAR1,OTHERCRITERIAVALUE1,DEFAULT)
      values ('A269','FAILDIST','','','')
      values ('A270','CUMULATIVEFAILDIST','','','')
      values ('A271','HAZARDFNC','','','')
      values ('A272','COUNT_CLUSTER','','','')
      values ('A273','PERCENT_CLUSTER','','','')
      values ('A274','COUNT_OVERALL','','','')
      values ('A275','PERCENT_OVERALL','','','')
      values ('A276','INPT','','','')
   ;

     insert into &parmslLibRef..ANLFORMATLABEL_LABEL_NLS
      (LOCALE,KEY,LINENO,TEXT)
      values ("&locale",'A269',1,"&a1")
      values ("&locale",'A270',1,"&a2")
      values ("&locale",'A271',1,"&a3")
      values ("&locale",'A272',1,"&a4")
      values ("&locale",'A273',1,"&a5")
      values ("&locale",'A274',1,"&a6")
      values ("&locale",'A275',1,"&a7")
      values ("&locale",'A276',1,"&a19")
    ;

    insert into &parmslLibRef..ANLFORMATLABEL_FORMAT_NLS
      (LOCALE,KEY,LINENO,TEXT)
      values ("&locale",'A273',1,'PERCENT8.2')
      values ("&locale",'A275',1,'PERCENT8.2')
   ;

   select KEY into :key
     from &parmslLibRef..ANLFORMATLABEL_BASE
     where VARNAME = 'CLAIMTISBIN'
   ;
    insert into &parmslLibRef..ANLFORMATLABEL_FORMAT_NLS
      (LOCALE,KEY,LINENO,TEXT)
      values ("&locale","&KEY",1,'NLNUM7.')
   ;

   create table work.keys as
     select KEY 
     from &parmslLibRef..ANLFORMATLABEL_BASE
     where upcase(VARNAME) in ('BUILDTOSALEMONTHCOUNT','BUILD_PERIOD','CLAIMMONTHEI','INSERVICE_PERIOD','SALETOCLAIMMONTHCOUNT')
   ;

   delete from &parmslLibRef..ANLFORMATLABEL_BASE
     where KEY in 
       (select KEY 
       from work.keys)               
   ;

   delete from &parmslLibRef..ANLFORMATLABEL_LABEL_NLS
     where KEY in 
       (select KEY 
       from work.keys)               
   ;

   delete from &parmslLibRef..ANLFORMATLABEL_FORMAT_NLS
     where KEY in 
       (select KEY 
       from work.keys)               
   ;


/* -------------------------------------------------------------- */
/* Updates to ANALYSISOPTIONATTRIBUTES_BASE Table                 */
/* - Updating a row                                               */
/* -------------------------------------------------------------- */

    update &parmslLibRef..Analysisoptionattributes_base set
     INPUTFIELDSOURCE='as_useremaillist(identitygroup=Warranty Analysis: Data Analysis,outdsname=emailaddrs)'
       where INPUTFIELDSOURCE='as_useremaillist(identitygroup=Warranty EI Administrator,outdsname=emailaddrs)'
   ;
   
    update &parmslLibRef..Analysisoptionattributes_base set
     INPUTFIELDTABLENUMROWS=1 where upcase(NAME)='COLORSCALE'
     ;
   
   update &parmslLibRef..Analysisoptionattributes_base
   set FORMATREGEX='[^,]*'
   where upcase(name) in ('USERTITLE' 'USERSUBTITLE' 'USERFOOTNOTE'
                          'DEFINEDHIERARCHYWHERE' 'PRODUCTWHERE' 'PRODUCTWHEREDISPLAY'
                          'CLAIMSWHERE' 'CLAIMSWHEREDISPLAY')
   ;


/* -------------------------------------------------------------- */
/* Updates to ANALYSISOPTIONS Table                               */
/* - Allowing default values for AVARS and changing space delimiter*/
/*   comma for multiple default values                            */
/* - Inserting rows                                               */
/* -------------------------------------------------------------- */

   update &parmslLibRef..analysisoptions set 
     ALLOWDEFAULTVALUE="1",
     DEFAULTVALUE=tranwrd(strip(defaultvalue),' ',',')
          where ANLOPTGROUPID="AVARS" and ANALYSISTYPE in (select ANALYSISTYPE from &parmslLibRef..analysistypes where RPTGROUP="MAIN")
   ;

   update &parmslLibRef..analysisoptions set 
     DEFAULTVALUE="on" where ANLOPTATTRID="AOA15" and upcase(DEFAULTVALUE)="TRUE";
   update &parmslLibRef..analysisoptions set 
     DEFAULTVALUE="off" where ANLOPTATTRID="AOA15" and upcase(DEFAULTVALUE)="FALSE";
 
   update &parmslLibRef..analysisoptions set 
     DEFAULTVALUE="95" where ANLOPTATTRID="AOA92";
   update &parmslLibRef..analysisoptions set 
     ISREQUIRED="1" where ANLOPTATTRID="AOA92";

   update &parmslLibRef..analysisoptions set 
     ALLOWDEFAULTVALUE="0" where ANLOPTATTRID="AOA21";
     
   update &parmslLibRef..analysisoptions set 
     ISREQUIRED="1" where ANLOPTATTRID="AOA40" and ANALYSISTYPE="TRENDEXP";
     
   update &parmslLibRef..analysisoptions set 
     ISREQUIRED="1" where ANLOPTATTRID="AOA95" and ANALYSISTYPE="TRENDEXP";
     
   update &parmslLibRef..analysisoptions set 
     DEFAULTVALUE="Blue" where ANALYSISTYPE="GEOGRAPHIC" and ANLOPTATTRID =
        (select ANLOPTATTRID from &parmslLibRef..Analysisoptionattributes_base
          where upcase(NAME)='COLORSCALE')
     ;

   insert into &parmslLibRef..analysisoptions
     (WARRANTYTYPE,ANALYSISTYPE,ANLOPTGROUPID,ANLOPTATTRID,PEERNUMBER,ISREQUIRED,ALLOWDEFAULTVALUE,DEFAULTVALUE)
      values("2","EIDRILLTOA","ANAL","AOA55",2,"0","0","")
      values("2","EIDRILLTOA","ANAL","AOA56",3,"0","0","")
      values("2","EIDRILLTOA","ANAL","AOA58",5,"0","0","")
      values("2","EIDRILLTOA","ANAL","AOA62",7,"0","0","")
      values("2","EIDRILLTOA","ANAL","AOA64",6,"0","0","")
      values("2","EIDRILLTOA","ANAL","AOA82",8,"0","0","")
      values("2","EIDRILLTOA","ANAL","AOA85",4,"0","0","")
      values("2","EIDRILLTOA","AVARS","AOA1",1,"0","0","")
      values("2","EIDRILLTO","EIASP","AOA54",1,"0","0","")
      values("2","EIDRILLTO","EIASP","AOA55",2,"0","0","")
      values("2","EIDRILLTO","EIASP","AOA56",3,"0","0","")
      values("2","EIDRILLTO","EIASP","AOA58",5,"0","0","")
      values("2","EIDRILLTO","EIASP","AOA64",7,"0","0","")
      values("2","EIDRILLTO","EIASP","AOA67",9,"0","0","")
      values("2","EIDRILLTO","EIASP","AOA68",10,"0","0","")
      values("2","EIDRILLTO","EIASP","AOA73",11,"0","0","")
      values("2","EIDRILLTO","EIASP","AOA74",12,"0","0","")
      values("2","EIDRILLTO","EIAV","AOA52",1,"0","0","")
      values("2","EIDRILLTO","EIAV","AOA53",2,"0","0","")
      values("2","EIDRILLTO","EIBRP","AOA60",1,"0","0","")
      values("2","EIDRILLTO","EIBRP","AOA61",2,"0","0","")
      values("2","EIDRILLTO","EIBRP","AOA62",3,"0","0","")
      values("2","EIDRILLTO","EIBRP","AOA63",4,"0","0","")
      values("2","EIDRILLTO","EIFLTR","AOA77",1,"0","0","")
      values("2","EIDRILLTO","EIFLTR","AOA78",2,"0","0","")
      values("2","EIDRILLTO","EIFLTR","AOA79",3,"0","0","")
      values("2","EIDRILLTO","EIFLTR","AOA80",4,"0","0","")
      values("2","EIDRILLTO","EIFLTR","AOA81",5,"0","0","")
      values("2","EIDRILLTO","EIFLTR","AOA82",12,"0","0","")
      values("2","EIDRILLTO","EIFLTR","AOA87",6,"0","0","")
      values("2","EIDRILLTO","EIFLTR","AOA88",7,"0","0","")
      values("2","EIDRILLTO","EIFLTR","AOA89",8,"0","0","")
      values("2","EIDRILLTO","EIFLTR","AOA91",10,"0","0","")
      values("2","EIDRILLTO","EIFLTR","AOA99",11,"0","0","")
      values("2","EIDRILLTO","EISS","AOA65",3,"0","0","")
      values("2","EIDRILLTO","EISS","AOA69",5,"0","0","")
      values("2","EIDRILLTO","EISS","AOA70",6,"0","0","")
      values("2","EIDRILLTO","EISS","AOA71",7,"0","0","")
      values("2","EIDRILLTO","EISS","AOA72",8,"0","0","")
      values("2","EIDRILLTO","EISS","AOA75",2,"0","0","")
      values("2","EIDRILLTO","EISS","AOA76",4,"0","0","")
      values("2","EIDRILLTO","EISS","AOA94",1,"0","0","")
       values ('2','EIANALYTIC','ANAL','AOA99',20,'1','1','N')
       values ('2','EITHRESHOLD','ANAL','AOA99',20,'1','1','N')
   ;


/* -------------------------------------------------------------- */
/* Updates to EIDETABLE and EIDHTABLE Tables                      */
/* - Adding DSANAME column                                        */
/* -------------------------------------------------------------- */

   alter table &parmslLibRef..EIDETABLE
     add DSANAME char(32) label='Data Selection Option Attribute Name'
   ;

   alter table &parmslLibRef..EIDHTABLE
     add DSANAME char(32) label='Data Selection Option Attribute Name'
   ;

/* -------------------------------------------------------------- */
/* Updates to SCREENATTRSVALUES_xxxx Table                        */
/* - Updating a column definition in BASE table                   */
/* - Modifying values for DisplayGrid                             */
/* -------------------------------------------------------------- */

   alter table &parmslLibRef..SCREENATTRSVALUES_BASE
     modify VALUE char(75)
   ;

   update &parmslLibRef..SCREENATTRSVALUES_BASE set 
     VALUE="on" where upcase(ATTRNAME)="DISPLAYGRID" and upcase(VALUE)="TRUE";
   update &parmslLibRef..SCREENATTRSVALUES_BASE set 
     VALUE="off" where upcase(ATTRNAME)="DISPLAYGRID" and upcase(VALUE)="FALSE";
     
   delete from &parmslLibRef..SCREENATTRSVALUES_BASE
          where upcase(ATTRNAME)='COLORSCALE' and upcase(VALUE) in ('GRAY', 'GREEN', 'RED')
          ;
     
   delete from &parmslLibRef..SCREENATTRSVALUES_NLS
          where upcase(KEY) in ('COLORSCALE10', 'COLORSCALE30', 'COLORSCALE40')
          ;



/* -------------------------------------------------------------- */
/* Updates to EIAUTOPARMS Table                                   */
/* - adding _dsaname parameters                                   */
/* -------------------------------------------------------------- */

    insert into &parmslLibRef..EIAUTOPARMS
      (DATASOURCEID, EIPG_ID, MACROVAR, MACROSTMT, TYPE)
      values ('1',0,'prodDate_dsaname','','H')
      values ('1',0,'saleDate_dsaname','','H') 
      values ('1',0,'claimdate_dsaname','S_CLAIM_REPAIR_START_DT','H')
      values ('1',0,'maxfperiod','','H')
   ;

/* -------------------------------------------------------------- */
/* Updates to ANALYSISTYPES_xxxx Tables                           */
/* - Adding EIDRILLTO and EIDRILLTOA Analysis                     */
/* - Updating Names for EI Analyses                               */
/* -------------------------------------------------------------- */

    insert into &parmslLibRef..ANALYSISTYPES_BASE
      (ANALYSISTYPE,SECURITYLEVEL,ORDER,DATAPREPMACRO,OUTPUTMACRO,CHILDRPTCRITERIA,RPTGROUP)
      values ('EIDRILLTO','user',160,'eidrilltodataprep','anl_eidrilltoOutput','PARETO TREND TRENDEXP EXPOSURE GEOGRAPHIC STATDRIVER MULTIVARIATE TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS','EIDRILLTO')
      values ('EIDRILLTOA','user',170,'eidrilltoadataprep','anl_eidrilltoaOutput','PARETO TREND TRENDEXP EXPOSURE GEOGRAPHIC STATDRIVER MULTIVARIATE TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS','EIDRILLTO')
   ;

    insert into &parmslLibRef..ANALYSISTYPES_NLS
      (LOCALE,KEY,LINENO,TEXT)
      values ("&locale",'EIDRILLTO',1,"&a8")
      values ("&locale",'EIDRILLTOA',1,"&a9")
    ;
    
    update &parmslLibRef..ANALYSISTYPES_NLS set 
     TEXT="&a10" where upcase(KEY)="EIAUTOMATED";
    update &parmslLibRef..ANALYSISTYPES_NLS set 
     TEXT="&a11" where upcase(KEY)="EIANALYTIC";
    update &parmslLibRef..ANALYSISTYPES_NLS set 
     TEXT="&a12" where upcase(KEY)="EITHRESHOLD";

   alter table &parmslLibRef..ANALYSISTYPES_BASE DROP CONSTRAINT primarykey;
   alter table &parmslLibRef..ANALYSISTYPES_BASE add constraint primarykey primary key ( ANALYSISTYPE );
   alter table &parmslLibRef..ANALYSISTYPES_BASE add constraint order unique ( ORDER ) message="ORDER must be unique";


/* -------------------------------------------------------------- */
/* Updates to analysissetupvariableusagele                        */
/* - Adding rows for EI analysis derived variables.               */
/* -------------------------------------------------------------- */

   insert into &parmslLibRef..analysissetupvariableusage
      (ANALYSISTYPE , VARIABLEID , NAME , REPORTINGVARIABLE , ANALYSISVARIABLE , BYVARIABLE , COMMENTVARIABLE )
      values('DETAIL','V174','BUILDTOSALEMONTHCOUNT','1','0','1','0')
      values('DETAIL','V175','BUILD_PERIOD','1','0','0','0')
      values('DETAIL','V176','CLAIMMONTHEI','1','0','0','0')
      values('DETAIL','V177','INSERVICE_PERIOD','1','0','0','0')
      values('DETAIL','V178','SALETOCLAIMMONTHCOUNT','1','0','1','0')
      values('DETAIL','V179','__INALERT__','1','0','1','0')
      values('EXPOSURE','V179','__INALERT__','0','0','1','0')
      values('MULTIVARIATE','V174','BUILDTOSALEMONTHCOUNT','1','0','1','0')
      values('MULTIVARIATE','V175','BUILD_PERIOD','1','0','0','0')
      values('MULTIVARIATE','V176','CLAIMMONTHEI','1','0','0','0')
      values('MULTIVARIATE','V177','INSERVICE_PERIOD','1','0','0','0')
      values('MULTIVARIATE','V178','SALETOCLAIMMONTHCOUNT','1','0','1','0')
      values('MULTIVARIATE','V179','__INALERT__','1','0','1','0')
      values('PARETO','V174','BUILDTOSALEMONTHCOUNT','1','0','1','0')
      values('PARETO','V175','BUILD_PERIOD','1','0','0','0')
      values('PARETO','V176','CLAIMMONTHEI','1','0','0','0')
      values('PARETO','V177','INSERVICE_PERIOD','1','0','0','0')
      values('PARETO','V178','SALETOCLAIMMONTHCOUNT','1','0','1','0')
      values('PARETO','V179','__INALERT__','1','0','1','0')
      values('RELIABILITY','V179','__INALERT__','0','0','1','0')
      values('STATDRIVER','V174','BUILDTOSALEMONTHCOUNT','1','0','1','0')
      values('STATDRIVER','V175','BUILD_PERIOD','1','0','0','0')
      values('STATDRIVER','V176','CLAIMMONTHEI','1','0','0','0')
      values('STATDRIVER','V177','INSERVICE_PERIOD','1','0','0','0')
      values('STATDRIVER','V178','SALETOCLAIMMONTHCOUNT','1','0','1','0')
      values('STATDRIVER','V179','__INALERT__','1','0','1','0')
      values('TEXTANALYSIS','V174','BUILDTOSALEMONTHCOUNT','1','0','1','0')
      values('TEXTANALYSIS','V175','BUILD_PERIOD','1','0','0','0')
      values('TEXTANALYSIS','V176','CLAIMMONTHEI','1','0','0','0')
      values('TEXTANALYSIS','V177','INSERVICE_PERIOD','1','0','0','0')
      values('TEXTANALYSIS','V178','SALETOCLAIMMONTHCOUNT','1','0','1','0')
      values('TEXTANALYSIS','V179','__INALERT__','1','0','1','0')
      values('TIMEOFCLAIM','V174','BUILDTOSALEMONTHCOUNT','0','0','1','0')
      values('TIMEOFCLAIM','V175','BUILD_PERIOD','0','0','0','0')
      values('TIMEOFCLAIM','V176','CLAIMMONTHEI','1','0','0','0')
      values('TIMEOFCLAIM','V177','INSERVICE_PERIOD','0','0','0','0')
      values('TIMEOFCLAIM','V178','SALETOCLAIMMONTHCOUNT','0','0','1','0')
      values('TIMEOFCLAIM','V179','__INALERT__','0','0','1','0')
      values('TREND','V175','BUILD_PERIOD','1','0','0','0')
      values('TREND','V179','__INALERT__','0','0','1','0')
      values('TRENDEXP','V174','BUILDTOSALEMONTHCOUNT','1','0','1','0')
      values('TRENDEXP','V175','BUILD_PERIOD','1','0','0','0')
      values('TRENDEXP','V176','CLAIMMONTHEI','1','0','0','0')
      values('TRENDEXP','V177','INSERVICE_PERIOD','1','0','0','0')
      values('TRENDEXP','V178','SALETOCLAIMMONTHCOUNT','1','0','1','0')
      values('TRENDEXP','V179','__INALERT__','1','0','1','0')
   ;

/* -------------------------------------------------------------- */
/* Updates to VARIABLES_xxxx Tables                               */
/* - Adding new rows for for EI analysis derived variables        */
/* -------------------------------------------------------------- */

   insert into &parmslLibRef..variables_base
      (VARIABLEID , DMTABLEID , DATATYPE, DATATYPEDETAIL, NAME , SOURCE , TYPE ,  SUBTYPE ,
      LOOKUPTABLELIBRARY , LOOKUPTABLENAME , LOOKUPTABLEWHERE , LOOKUPTABLEDESCRIPTIONCOLUMN , LOOKUPTABLEKEYCOLUMN , DSDSVARIABLE )
      values('V174','','P','','BUILDTOSALEMONTHCOUNT','EICV','N','','','','','','','0')
      values('V175','','P','','BUILD_PERIOD','EICV','N','date','','','','','','0')
      values('V176','','C','','CLAIMMONTHEI','EICV','N','date','','','','','','0')
      values('V177','','P','','INSERVICE_PERIOD','EICV','N','date','','','','','','0')
      values('V178','','C','','SALETOCLAIMMONTHCOUNT','EICV','N','','','','','','','0')
      values('V179','','P','','__INALERT__','EICV','C','','','','','','','0')
   ;


   insert into &parmslLibRef..variables_label_nls
      (LOCALE,KEY,LINENO,TEXT)
      values("&locale",'V174',1,"&a13")
      values("&locale",'V175',1,"&a14")
      values("&locale",'V176',1,"&a15")
      values("&locale",'V177',1,"&a16")
      values("&locale",'V178',1,"&a17")
      values("&locale",'V179',1,"&a18")
   ;

   insert into &parmslLibRef..variables_format_nls
      (LOCALE,KEY,LINENO,TEXT)
                values("&locale",'V175',1,'NLDATE.')
                values("&locale",'V176',1,'NLDATE.')
      values("&locale",'V177',1,'NLDATE.')
   ;

/* --------------------------------------------------------------- */
/* Updates to DATASELECTIONATTRIBUTES_BASE and DSATTRS_xxxx Tables */
/* - Adding new rows for EI analysis derived variables             */
/* - defect S0682090                                               */
/* --------------------------------------------------------------- */

   select max(input(substr(dsattrid,4),best12.))+1 into :l_newdsattrid
   from &parmslLibRef..dataselectionattributes_base
      ;
   
   %let ll_newdsattrid=DSA%left(&l_newdsattrid);
   %put ll_newdsattrid=&ll_newdsattrid;

        insert into &parmslLibRef..dataselectionattributes_base
           set dsattrid = "&ll_newdsattrid", name = 'S_BUILD_PERIOD', variableids = 'V175',
               inputfieldtype = 'DateDataType', isrange = '1', datetype = 'DATE', 
               datestylepattern = 'LONG' , logicaloperator = 'BETWEEN';
               
        insert into &parmslLibRef..dsattrs_format_nls
           set key = "&ll_newdsattrid", locale = "&locale", lineno = 1, text = 'NLDATE.';
                    
        insert into &parmslLibRef..dsattrs_label_nls
           set key = "&ll_newdsattrid", locale = "&locale", lineno = 1, text = "&a14";

   %let l_newdsattrid=%trim(%eval(&l_newdsattrid+1));
   %let ll_newdsattrid=DSA%left(&l_newdsattrid);
   %put ll_newdsattrid=&ll_newdsattrid;

        insert into &parmslLibRef..dataselectionattributes_base
           set dsattrid = "&ll_newdsattrid", name = 'S_CLAIMMONTHEI', variableids = 'V176',
               inputfieldtype = 'DateDataType', isrange = '1', datetype = 'DATE', 
               datestylepattern = 'LONG' , logicaloperator = 'BETWEEN';
               
        insert into &parmslLibRef..dsattrs_format_nls
           set key = "&ll_newdsattrid", locale = "&locale", lineno = 1, text = 'NLDATE.';
                     
        insert into &parmslLibRef..dsattrs_label_nls
           set key = "&ll_newdsattrid", locale = "&locale", lineno = 1, text = "&a15"; 

   %let l_newdsattrid=%trim(%eval(&l_newdsattrid+1));
   %let ll_newdsattrid=DSA%left(&l_newdsattrid);
   %put ll_newdsattrid=&ll_newdsattrid;

        insert into &parmslLibRef..dataselectionattributes_base
           set dsattrid = "&ll_newdsattrid", name = 'S_INSERVICE_PERIOD', variableids = 'V177',
               inputfieldtype = 'DateDataType', isrange = '1', datetype = 'DATE', 
               datestylepattern = 'LONG' , logicaloperator = 'BETWEEN';
               
        insert into &parmslLibRef..dsattrs_format_nls
           set key = "&ll_newdsattrid", locale = "&locale", lineno = 1, text = 'NLDATE.';
                      
        insert into &parmslLibRef..dsattrs_label_nls
           set key = "&ll_newdsattrid", locale = "&locale", lineno = 1, text = "&a16";            

   %let l_newdsattrid=%trim(%eval(&l_newdsattrid+1));
   %let ll_newdsattrid=DSA%left(&l_newdsattrid);
   %put ll_newdsattrid=&ll_newdsattrid;
   
        insert into &parmslLibRef..dataselectionattributes_base
           set dsattrid = "&ll_newdsattrid", name = 'S___INALERT__', variableids = 'V179',
               inputfieldtype = 'FreeTextDataType', logicaloperator = 'IN';

        insert into &parmslLibRef..dsattrs_label_nls
           set key = "&ll_newdsattrid", locale = "&locale", lineno = 1, text = "&a18"; 
           

/* -------------------------------------------------------------- */
/* Updates to SWADATATYPES_BASE Table                             */
/* - Adding a new column                                          */
/* -------------------------------------------------------------- */

   alter table &parmslLibRef..SWADATATYPES_BASE add DMTABLEUFID char(32) label="Data Mart Table User-friendly ID for Primary Key";

   update &parmslLibRef..SWADATATYPES_BASE set DMTABLEUFID='warranty_claim_id' where DMTABLEPK='warranty_claim_sk';
   update &parmslLibRef..SWADATATYPES_BASE set DMTABLEUFID='product_id' where DMTABLEPK='product_sk';


/* -------------------------------------------------------------- */
/* Updates to TOCREPORTVARTABLE Table                             */
/* - Adding a new rows to enable Gaps in lines                    */
/* -------------------------------------------------------------- */ 

   insert into &parmslLibRef..tocreportvartable
      (DATASOURCEID,REPORTVAR,CLAIMPERIOD,SALEPERIOD,BUILDPERIOD,INTERVALPERIOD,EXTRAPOLATEDVAR)
      values('1','PRODUCTION_YEAR_CD','','','','Year','')
      values('1','INSERVICE_MONTH','','','','Month','')
      values('1','IN_SERVICE_DT','','','','Day','')
      values('1','IN_SERVICE_YEAR_CD','','','','Year','')
      values('1','PRODUCTION_DT','','','','Day','')
      values('1','SHIP_DT','','','','Day','')
      values('1','SHIP_YEAR_CD','','','','Year','')
      ;


/* -------------------------------------------------------------- */
/* Updates to JOBSYNCHLOCK table                                  */
/* -------------------------------------------------------------- */
   
   drop table &parmslLibRef..JOBSYNCHLOCK;
   
   create table &parmslLibRef..JOBSYNCHLOCK (label='Job Control Lock')
   (
      ISLOCKED                    char(1) label='Is Locked',
      WHOLOCKING                  char(64),
      DTSTAMP                     num(8) format=datetime.
   )
   ;
   
   insert into &parmslLibRef..JOBSYNCHLOCK
   set islocked='N',wholocking='NONE',dtstamp=datetime()
   ;


/* -------------------------------------------------------------- */
/* Delete unused tables and views                                 */
/* - ANLCALCMETHODS, CALCMETHODS, DATATYPEDETAILDESC              */
/* -------------------------------------------------------------- */

   drop table &parmslLibRef..ANLCALCMETHODS;

   drop view &parmslLibRef..CALCMETHODS;
   drop table &parmslLibRef..CALCMETHODS_BASE;
   drop table &parmslLibRef..CALCMETHODS_NLS;

   drop table &parmslLibRef..DATATYPEDETAILDESC;


/* ----------------------------------------------------------------- */
/* Updates to USERATTRIBUTES table                                   */
/* - replace values in AUTHOR column in several USERDL tables first  */
/* - change primary key to PERSONOMRNAME                             */
/* - drop LOGINID and PERSONOMRID columns                            */
/* ----------------------------------------------------------------- */

   update &userdlLibRef..PROJECT_WORKSPACE a
      set author = (select personomrname from &parmslLibRef..USERATTRIBUTES b
                     where a.author=b.loginid
                        or scan(a.author,2,'/')=b.loginid
                        or scan(a.author,2,'\')=b.loginid
                        or scan(a.author,1,'@')=b.loginid
                   )
   ;
   
   update &userdlLibRef..REPORT_WORKSPACE a
      set author = (select personomrname from &parmslLibRef..USERATTRIBUTES b
                     where a.author=b.loginid
                        or scan(a.author,2,'/')=b.loginid
                        or scan(a.author,2,'\')=b.loginid
                        or scan(a.author,1,'@')=b.loginid
                   )
   ;

   update &userdlLibRef..usr_cfilters a
      set author = (select personomrname from &parmslLibRef..USERATTRIBUTES b
                     where a.author=b.loginid
                        or scan(a.author,2,'/')=b.loginid
                        or scan(a.author,2,'\')=b.loginid
                        or scan(a.author,1,'@')=b.loginid
                   )
   ;

   update &userdlLibRef..usr_esc a
      set author = (select personomrname from &parmslLibRef..USERATTRIBUTES b
                     where a.author=b.loginid
                        or scan(a.author,2,'/')=b.loginid
                        or scan(a.author,2,'\')=b.loginid
                        or scan(a.author,1,'@')=b.loginid
                   )
   ;

   update &userdlLibRef..usr_pboc a
      set author = (select personomrname from &parmslLibRef..USERATTRIBUTES b
                     where a.author=b.loginid
                        or scan(a.author,2,'/')=b.loginid
                        or scan(a.author,2,'\')=b.loginid
                        or scan(a.author,1,'@')=b.loginid
                   )
   ;

   update &userdlLibRef..usr_psc a
      set author = (select personomrname from &parmslLibRef..USERATTRIBUTES b
                     where a.author=b.loginid
                        or scan(a.author,2,'/')=b.loginid
                        or scan(a.author,2,'\')=b.loginid
                        or scan(a.author,1,'@')=b.loginid
                   )
   ;

   update &userdlLibRef..usr_sfilters a
      set author = (select personomrname from &parmslLibRef..USERATTRIBUTES b
                     where a.author=b.loginid
                        or scan(a.author,2,'/')=b.loginid
                        or scan(a.author,2,'\')=b.loginid
                        or scan(a.author,1,'@')=b.loginid
                   )
   ;

   update &userdlLibRef..EI_workspace a
      set author = (select personomrname from &parmslLibRef..USERATTRIBUTES b
                     where a.author=b.loginid
                        or scan(a.author,2,'/')=b.loginid
                        or scan(a.author,2,'\')=b.loginid
                        or scan(a.author,1,'@')=b.loginid
                   )
   ;

   update &userdlLibRef..usr_subsetting a
      set author = (select personomrname from &parmslLibRef..USERATTRIBUTES b
                     where a.author=b.loginid
                        or scan(a.author,2,'/')=b.loginid
                        or scan(a.author,2,'\')=b.loginid
                        or scan(a.author,1,'@')=b.loginid
                   )
   ;

   create table USERATTRIBUTES as
      select * from &parmslLibRef..USERATTRIBUTES
   ;

   %global sastrust41loginid;
   select loginid into :sastrust41loginid
     from &parmslLibRef..USERATTRIBUTES
    where DIRECTORYNAME='00000000'
   ;
    
   update USERATTRIBUTES
    set PERSONOMRNAME='sastrust' where DIRECTORYNAME='00000000'
   ;

   drop table &parmslLibRef..userattributes;

   create table &parmslLibRef..USERATTRIBUTES (label='User Attributes',
      LOGINID                     char(32) label='Login ID',
      PERSONOMRNAME               char(64) label='OMR Person Name',
      DIRECTORYNAME               char(32) label='User Directory Name for Logs and Data Selections',
      SERVERNAME                  char(64) label='Server Name for User Data Selections (Must match host-defined value: Win=value of environment variable COMPUTERNAME, unix=value from hostname cmd.)',
      SERVERPATH                  char(300) label='Directory Path on Server for User Data Selections',
      CURRENCYCODE                char(6) label='Currency Code',
      constraint primarykey primary key ( PERSONOMRNAME )  
   );

   insert into &parmslLibRef..userattributes 
      select loginid
           , personomrname
           , directoryname
           , servername
           , serverpath
           , currencycode
        from userattributes
   ;


/* -------------------------------------------------------------- */
/* Updates to PARMSL tables for I18N                              */
/* -------------------------------------------------------------- */

   alter table &parmslLibRef..ANLFORMATLABEL_LABEL_NLS
   modify TEXT char(150)
   ;

   alter table &parmslLibRef..DATASOURCEGROUPS_WTDESC_NLS
   modify TEXT char(250)
   ;

   alter table &parmslLibRef..LOCALE_LIST_NLS
   modify TEXT char(250)
   ;

   alter table &parmslLibRef..SWADATATYPES_NLS
   modify TEXT char(100)
   ;

   alter table &parmslLibRef..USERTITLETOKENS_NLS
   modify TEXT char(100)
   ;

   alter table &parmslLibRef..VARIABLES_LABEL_NLS
   modify TEXT char(250)
   ;
   

/* -------------------------------------------------------------- */
/* Updates to EIOUT tables                                        */
/* -------------------------------------------------------------- */

   alter table &eioutLibRef..eiruntrack modify ownerId CHAR(64); 
   alter table &eioutLibRef..eireporttrack modify ownerId CHAR(64); 
   

/* ----------------------------------------------------------------- */
/* Updates to USERDL tables                                          */
/* - usr_sfilters, usr_cfilters and usr_subsetting                   */
/* - adding columns FSOWNER, FS_LAST_ACCESS_DATE, FS_PENDING DELETE  */
/* - and FILTEROPTIONS to usr_sfilters                               */
/* ----------------------------------------------------------------- */

   alter table &userdlLibRef..usr_sfilters
      add fsowner char(200)label='Current Filter Subset Owner'
      add fs_last_access_date num format=NLDATE. label='Filter Subset Last Access Date'
      add fs_pending_delete char(1)
      add FilterOptions char(1) label='Does Options Table Exist'
      ;

   alter table &userdlLibRef..usr_cfilters
      add fsowner char(200)label='Current Filter Subset Owner'
      add fs_last_access_date num format=NLDATE. label='Filter Subset Last Access Date'
      add fs_pending_delete char(1)
      add FilterOptions    CHAR(1) label='Does Options Table Exist'
      ;

   alter table &userdlLibRef..usr_subsetting
      add fsowner char(200)label='Current Filter Subset Owner'
      add fs_last_access_date num format=NLDATE. label='Filter Subset Last Access Date'
      add fs_pending_delete char(1)
      ;

   create table &userdlLibRef..subscription (
      Subscription_Id   Char(80),
      isActive            Char(1),
      ModDate            Num format=NLDATM. informat=NLDATM.,
      sendEmail         Char(1),
      EiType            Char(15),
      RunGroupId        Char(80),
     RunGroupName      Char(271),
      RunGroupDesc      Char(400),
      OmRpersonName     Char(64), /* Seetha, I don't know what length should be */
      constraint primarykey primary key (Subscription_Id) 
   );

   create table &userdlLibRef..subscription_details (
      Subscription_Id   Char(80),
      Variable_id       Char(8),
      Variable_name     Char(32),
      Variable_label    Char(60), /*Seetha, its 60 on variables, don't know why. May want to use 256?*/
      variable_values   Char(8000), /* Seetha, using 8000 on analysis options, so... */
      exclude_values      Char(1),
      Component_id      Num(4)
   );
   create index Subscription_Id on &userdlLibRef..subscription_details; 

   /************Modifying usr_sfilters for data selection going out of date error**************/

   create table &userdlLibRef..usr_sfilters (rename=(etl_datetime=warehouse_datetime) )
     as select * from &userdlLibRef..usr_sfilters
   ;

   alter table &userdlLibRef..usr_sfilters 
     modify warehouse_datetime label="from parmsl.warehouse_refresh.Warehouse_refresh_Datetime"
   ;

   alter table &userdlLibRef..usr_sfilters
      add etl_datetime num(8) label='from &parmslLibRef..warehouse_refresh.etl_refresh_Datetime' FORMAT=nldatm.
   ;

   /****If the data selection is not outdated ... update the value of etl_datetime with parmsl.warehouse_refresh.etl-datetime *****/

   Update &userdlLibRef..USR_SFILTERS t1
   set ETL_DATETIME=
      (select t2.SWAETL_REFRESH_DATETIME 
            from &parmslLibRef..WAREHOUSE_REFRESH as t2 
            where t1.WAREHOUSE_DATETIME=t2.WAREHOUSE_REFRESH_DATETIME AND T1.datasourceid = T2.datasourceid)
   WHERE  T1.WAREHOUSE_DATETIME NE .
   ;

   /**** If the data selection is outdated... update the value of etl-datetime with usr_sfilters.warehouse-datetime ****/

   Update &userdlLibRef..USR_SFILTERS t1
   set ETL_DATETIME=T1.WAREHOUSE_DATETIME
   WHERE WAREHOUSE_DATETIME NE . AND WAREHOUSE_DATETIME NOT IN  
      (select WAREHOUSE_REFRESH_DATETIME FROM &parmslLibRef..WAREHOUSE_REFRESH T2 WHERE T1.datasourceid = T2.datasourceid)
   ;

   /************Modifying usr_cfilters for data selection going out of date error**************/

   create table &userdlLibRef..usr_cfilters (rename=(etl_datetime=warehouse_datetime) )
     as select * from &userdlLibRef..usr_cfilters
   ;

   alter table &userdlLibRef..usr_cfilters 
     modify warehouse_datetime label="from parmsl.warehouse_refresh.Warehouse_refresh_Datetime"
   ;

   alter table &userdlLibRef..usr_cfilters
      add etl_datetime num(8) label='from &parmslLibRef..warehouse_refresh.etl_refresh_Datetime' FORMAT=nldatm.
   ;

   Update &userdlLibRef..USR_cFILTERS t1
   set ETL_DATETIME=
      (select t2.SWAETL_REFRESH_DATETIME 
            from &parmslLibRef..WAREHOUSE_REFRESH as t2 
            where t1.WAREHOUSE_DATETIME=t2.WAREHOUSE_REFRESH_DATETIME AND T1.datasourceid = T2.datasourceid)

   WHERE  T1.WAREHOUSE_DATETIME NE .
    ;

   Update &userdlLibRef..USR_cFILTERS t1
   set ETL_DATETIME=T1.WAREHOUSE_DATETIME
   WHERE WAREHOUSE_DATETIME NE . AND WAREHOUSE_DATETIME NOT IN  
      (select WAREHOUSE_REFRESH_DATETIME FROM &parmslLibRef..WAREHOUSE_REFRESH T2 WHERE T1.datasourceid = T2.datasourceid)
    ;

   /************Modifying usr_subsetting for data selection going out of date error**************/

   create table &userdlLibRef..usr_subsetting (rename=(etl_datetime=warehouse_datetime) )
     as select * from &userdlLibRef..usr_subsetting
   ;

   alter table &userdlLibRef..usr_subsetting 
     modify warehouse_datetime label="from parmsl.warehouse_refresh.Warehouse_refresh_Datetime"
   ;

   alter table &userdlLibRef..usr_subsetting
      add etl_datetime num(8)label='from parmsl.warehouse_refresh.etl_refresh_Datetime' FORMAT=nldatm.
   ;

   Update &userdlLibRef..usr_subsetting t1
   set ETL_DATETIME=
      (select t2.SWAETL_REFRESH_DATETIME 
            from &parmslLibRef..WAREHOUSE_REFRESH as t2 
            where t1.WAREHOUSE_DATETIME=t2.WAREHOUSE_REFRESH_DATETIME AND T1.datasourceid = T2.datasourceid)

   WHERE  T1.WAREHOUSE_DATETIME NE .
    ;

   Update &userdlLibRef..usr_subsetting t1
   set ETL_DATETIME=T1.WAREHOUSE_DATETIME
   WHERE WAREHOUSE_DATETIME NE . AND WAREHOUSE_DATETIME NOT IN  
      (select WAREHOUSE_REFRESH_DATETIME FROM &parmslLibRef..WAREHOUSE_REFRESH T2 WHERE T1.datasourceid = T2.datasourceid)
    ;
