/*
+-----------------------------------------------------------------+
| NAME:                                                           |
| swa431_migration.sql                                            |
|                                                                 |
| TYPE:                                                           |
| SQL code                                                        |
|                                                                 |
| DESCRIPTION:                                                    |
| This script contains SQL statements for updating SAS Warranty   |
| Analysis 4.3.1 tables when there is a migration from an earlier |
| version of SWA.                                                 |
|                                                                 |
|                                                                 |
| SAS VERSION:                                                    |
| This software unit was developed for version 9.3                |
|                                                                 |
| HISTORY:                                                        |
| sascis    08Apr2011   Initial coding                            |
| sindok    19Jul2011   Added FailRel items for S0776148          |
| sascis    25Jan2012   S0826550: fill author with personOMRname  |
+-----------------------------------------------------------------+
+-----------------------------------------------------------------+
| Copyright (c) 2012 by SAS Institute Inc., Cary, NC 27513 USA    |
| ---All Rights Reserved.                                         |
+-----------------------------------------------------------------+
*/

/* -----------------------------------------------------------------------*/
/*                                                                        */
/* ---------------------------------------------------------------------- */

%macro sql_updates;
   proc sql noprint;

      select * from &parmslLibRef..AnalysisSetupVariableUsage      
       where upcase(ANALYSISTYPE)="TREND" and upcase(VARIABLEID)="V069" and upcase(NAME)="CLAIMCOST";
   %if &sqlobs EQ 0 %then
   %do;
      insert into &parmslLibRef..AnalysisSetupVariableUsage      /* S0730404 */
             (ANALYSISTYPE,VARIABLEID,NAME,REPORTINGVARIABLE,ANALYSISVARIABLE,
              BYVARIABLE,COMMENTVARIABLE)
      values ("TREND","V069","CLAIMCOST","0","1","0","0");
   %end;

      update &parmslLibRef..AnalysisPDFTemplate                  /* S0710046 */
         set GENERATEFLAG='1' 
       where ANALTYPE='TRENDEXP' and ARTIFACT='summarized';
   
      select * from &parmslLibref..analysisMacVars
       where upcase(ANALYSISTYPE)='FAILREL' and lowcase(MACROVAR)='tispointofview';
   %if &sqlobs EQ 0 %then
   %do;
      insert into &parmslLibref..analysisMacVars                 /* S0756811 */
             (ANALYSISTYPE,MACROVAR,MACROSTMT)
      values ('FAILREL','tispointofview','fromBuild');
   %end;
   
      select * from &parmslLibref..analysisMacVars
       where upcase(ANALYSISTYPE)='FAILREL' and lowcase(MACROVAR)='pseudoliftincludeflag';
   %if &sqlobs EQ 0 %then
   %do;
      insert into &parmslLibref..analysisMacVars                 /* S0776148 */               
             (ANALYSISTYPE,MACROVAR,MACROSTMT)
      values ('FAILREL','pseudoLiftIncludeFlag','N');            /*dk*/
   %end;
  	
      select * from  &parmslLibRef..ANLFORMATLABEL_BASE
       where upcase(KEY)='A274' and lowcase(VARNAME)='pseudolift';
   %if &sqlobs EQ 0 %then
   %do;
      insert into &parmslLibRef..ANLFORMATLABEL_BASE             /* S0776148 */          
             (KEY,VARNAME,OTHERCRITERIAVAR1,OTHERCRITERIAVALUE1,DEFAULT)
      values ('A274','PseudoLift','','','');                     /*dk*/
   %end;
      
      update &parmslLibref..analysisOptionAttributes_base        /* S0756807 */
         set PRECISION=2
       where ANLOPTATTRID='AOA153';
    
      select * from &parmslLibref..modulesDefinition
       where upcase(modulename) = 'UTIL_COPYEIAUTOSFOPTIONS';
   %if &sqlobs EQ 0 %then
   %do;
      insert into &parmslLibref..modulesDefinition               /* S0757295 */
             (MODULENAME,MODULECONTROLLER)
      values ('UTIL_COPYEIAUTOSFOPTIONS','%util_copyeiautosfoptions');
   %end;

   /* --------------------------------------------------------------------------------- */
   /* S0826550: include updates for author-type columns that still many contain loginid */
   
   select name 
     from dictionary.columns
    where upcase(libname) = upcase("&parmslLibref.") 
      and upcase(memname) = "USERATTRIBUTES" 
      and upcase(name) = "LOGINID";
           
   %if &sqlobs GT 0 %then  /* this means the migration is from 4.1, because the column still exists */
   %do;

   update &userdlLibref..analysis_option_templates as main 
      set author = (select personOMRname from &parmslLibRef..UserAttributes as lkup
                     where upcase(strip(main.author)) = upcase(strip(lkup.loginid)))
   ;

   update &userdlLibref..preference_node as main
      set created_by = (select personOMRname from &parmslLibRef..UserAttributes as lkup
                         where upcase(strip(main.created_by)) = upcase(strip(lkup.loginid)))
   ;

   update &userdlLibref..preference_node as main
      set modified_by = (select personOMRname from &parmslLibRef..UserAttributes as lkup
                         where upcase(strip(main.modified_by)) = upcase(strip(lkup.loginid)))
    where modified_by is not missing
   ;

   update &userdlLibref..preference_node as main
      set node_name = (select personOMRname from &parmslLibRef..UserAttributes as lkup
                         where upcase(strip(main.node_name)) = upcase(strip(lkup.loginid)))
    where parent_node_id is not missing
   ;

   update &userdlLibref..preference_node as main
      set node_path = (select cats('/swa/',personOMRname) as node_path from &parmslLibRef..UserAttributes as lkup
                         where upcase(strip(main.node_path)) contains upcase(strip(lkup.loginid)))
    where parent_node_id is not missing
   ;

   update &userdlLibref..preference_property as main
      set created_by = (select personOMRname from &parmslLibRef..UserAttributes as lkup
                         where upcase(strip(main.created_by)) = upcase(strip(lkup.loginid)))
   ;

   update &userdlLibref..preference_property as main
      set modified_by = (select personOMRname from &parmslLibRef..UserAttributes as lkup
                         where upcase(strip(main.modified_by)) = upcase(strip(lkup.loginid)))
    where modified_by is not missing
   ;
   
   alter table &parmslLibRef..UserAttributes
      drop loginid  /* now it is no longer needed */
   ;
   
   %end;  /* only do these steps if the migration is from 4.1 */
   /* --------------------------------------------------------------------------------- */
   
   quit;
%mend;

%sql_updates;
