/*
+-----------------------------------------------------------------+
| NAME:                                                           |
| swa43_migration.sql                                             |
|                                                                 |
| TYPE:                                                           |
| SQL code                                                        |
|                                                                 |
| DESCRIPTION:                                                    |
| This script contains SQL statements for updating SAS Warranty   |
| Analysis 4.3 tables when there is a migration from an earlier   |
| version of SWA.                                                 |
|                                                                 |
|                                                                 |
| SAS VERSION:                                                    |
| This software unit was developed for version 9.2                |
|                                                                 |
| HISTORY:                                                        |
| sinsav    26Mar2010   Initial version                           |
| atbroo    26May2010   Updated for changes to userattributes     |
| atbroo    02Jun2010   Updated for reliability drill to          |
| wehuan    03Jun2010   Updated for reliability biweibull         |
|                       distribution                              | 
| sasjal    14Jun2010   Made corrections for changes made on      |
|                       26May2010 and 03Jun2010                   |
| sasjal    15Jun2010   Updated for defect S0642442               |
|                       * variables_base - add V180,COSTINDEX     |
|                       * variables_label_nls - add V180,         |
|                         COSTINDEX label                         |
|                       * variables_format_nls - add V180,        |
|                         COSTINDEX format                        |
|                       * updates to ANLFORMATLABEL_xxxx tables   |
|                         to remove COSTINDEX                     |
| sasjal    15Jun2010   Updated for defect S0607095               |
|                       * eiautorungroups - drop ei_runint        |
|                       * updates to ANALYSISOPTIONATTRIBUTES_xxxx|
|                         to remove ei_runint                     |
|                       * ANALYSISOPTIONS - remove ei_runint      |
| sasjal    18Jun2010   Updated for defect S0652213               |
|                       * eiautoparms - add destartdate and       |
|                         einorecalc parameters                   |
| sasezw    21Jun2010   Updated for defect S0565881               |
|                       * added line for macro                    |
|                         util_getEIanalysisIDs                   |
| sinkah    29Jun2010   Updated for defect S0645273               |
|                       * Parmsl.Analysismacvars rows deleted     |
|                       * Parmsl.analyisistypes_base row updated  | 
| sinkah    29Jun2010   Updated for defect S0641789               |
|                       * Parmsl.Analysismacvars added variable   |
|                         Barcellvar                              |
| sinsav    30Jun2010   Updated for requirement defect S0644878   |
|                       * parmsl.security_options table added     |
| sinsav    30Jun2010   Updated for requirement defect S0642443   |
|                       * parmsl.AnalysisOptions modified to add  |
|                         ALLOWSTEMPLATES flag                    |
|                       * userdl.analysis_option_templates added  |
| sinsaa    30Jun2010   Updated for requirement defect S0643181   |
|                       * parmsl.Analysismacvars rows added       |
|                       * PARMSL.analysisoptionattributes_base    |
|                       * PARMSL.analysisoptionattributes_nls     |
|                       * PARMSL.analysisoptions                  |
|                       * PARMSL.analysissetupvariableusage       |
|                       * PARMSL.analysistypes_nls                |
|                       * PARMSL.analysistypes_base               |                                                       
|sinsav     09Jul2010   removed the duplicate sql added  on       |
|                       30Jun2010 for defect S0642443             |
| sinsaa    14Jul2010   Updated for defect S0680882               |
| sasjal    14Jul2010   Made the following corrections:           |
|                       * Moved Bars in Cells updates (S0641789)  |
|                         to swa43_migration.sas because of       |
|                         truncation issues.                      |
|                       * Added unmatched quote for MODULENAME    |
|                         value (S0565881)                        |
|                       * Double quoted macro variables for       |
|                         Summary Tables (S0643181) in            |
|                         PARMSL.analysisoptionsattributes_nls    |
|                       * Double quoted macro variables for       |
|                         Summary Tables (S0643181) in            |
|                         PARMSL.analysistypes_nls                |
|                       * Double quoted macro variables for       |
|                         Summary Tables (S0680882) in            |
|                         PARMSL.anlformatlabel_nls               |
|                       * Changed "maxnumbar" to "maxnumbars" and |
|                         UPCASED to ensure no case differences   |
|                         for S0645273                            |
| sasjal    19Jul2010   All of the above enhancements/changes     |
|                       have been tested.                         |
| sasjal    23Jul2010   Updated for defect S0642445               |
|                       * Added rows to PARMSL.MODULESDEFINITION  |
|                         for export to spreadsheet and PDF       |
| sasjal    23Jul2010   The above enhancements/changes            |
|                       have been tested.                         |
| sinkah    30Jul2010   Added script for Failure Relationship     |
|                        Migration                                | 
| wehuan    06Aug2010   modify value for MVD defect S0657609      |
| sasjal    17Aug2010   Added conditional execution for S0657609  |
|                       as we only want to change it if the       |
|                       value has not been changed for a site.    |
| sasjal    18Aug2010   Removed "barcellvar" entry for failure    |
|                       relationship as it's addressed in         |
|                       swa43_migration.sas -- changes pushed     |
|                       with S0657609.                            |
| sasjal    18Aug2010   The above enhancements/changes            |
|                       have been tested.                         |
| sindok    20Aug2010   Added assocTableThreshold for FAILREL     |
|                       analysis in analysismacvars dataset.      |
|                       (S0679492)                                |
| sindok    20Aug2010   Added maxLinkNumber and maxNodeNumber     |
|                       for FAILREL analysis in analysismacvars   |
|                       dataset. (S0694645)                       |  
| sasjal    23Aug2010   Defect S0585374:                          |
|                       * Rows added to PARMSL.analysistypes_base |
|                       * Rows added to PARMSL.anslysistypes_nls  |
|                       * Rows added to PARMSL.modulesdefinition  |
| sasjal    24Aug2010   The above enhancements/changes            |
|                       have been tested.                         |
| sinkah    25Aug2010   Updated for defects S0691029 and S0685613 |
| sindok    26Aug2010   Changed values of assocTableThreshold,    |
|                       maxLinkNumber, and maxNodeNumber for      |
|                       FAILREL in analysismacvars dataset.       |
| sinsaa    26Aug2010   Fixed defect S0687182 added values in     |
|                       * PARMSL.analysisoptionattributes_base    |
| sinsaa    26Aug2010   Fixed defect S0686719                     |
|                       * PARMSL.analysistypes_base               |
| sasjal    26Aug2010   Fixed code for defect S0686719            |
|                       * PARMSL.analysistypes_base               |
|                         Changed to update versus insert for all |
|                         analytics besides CROSSTAB.             |
| sindok    30Aug2010   Removed following entries from            | 
|                       analysismacvars for FAILREL analysis      |
|                       as they represent metadata which is not   |
|                       required:                                 |                                                                                             
|                       1. resultSize                             |
|                       2. seqVar                                 |
|                       3. idVarSeq                               |
|                       4. idVarAssoc                             |
|                       Changed value of testMode from 1 to 0.    |
| sasjal    30Aug2010   The above enhancements/changes            |
|                       have been tested.                         |
| sindok    31Aug2010   Where applicable, Changed values of       |
|                       SUPPORTVALPERCENT & CONFVALPERCENT        |    
|                       in Screenattrsvalues_base dataset, from   |
|                       integer to float.                         |
| sasjal    03Sep2010   The above enhancements/changes            |
|                       have been tested.                         |
| sindok    14Sep2010   Added seqProcThreshold as an entry in     |
|                       analysismacvars dataset. Changed value of |
|                       maxNodeNumber to 300.                     |
| sindok    17Sep2010   For AOA146, AOA147, AOA149 - set value of |
|                       'Allow admin to set default values?' - to |
|                       0. Also, set the DEFAULTVALUE of AOA149   |
|                       to FALSE.                                 |
| sinsaa    23Sep2010   Fixed defect S0702076                     |
|                       ALLOWDEFAULTVALUE for AOA157,AOA153,      |
|                       AOA154,AOA4,AOA8,AOA33,AOA34 have been    |
|                       assigned                                  |
| sascis    24Sep2010   Fix for defect S0700242                   |
|                       adding a row to MODULESDEFINITION         |
| sinsaa    27Sep2010   Fix for defect S0702516                   |
|                       adding a row to Anlformatlabel_base and   |
|                       Anlformatlabel_nls                        |
| sinsaa    29Sep2010   Made the changes for analysistypes_base   |
|                       that were missing for FAILREL             |                       
| sinsav    04Oct2010   Defect S0704945 ( Saved date are not      |
|                       correct when saving template)             | 
| sinsaa    11Oct2010   Defect S0666407,to create failrel         |
|                       LABORCD_TRIVIALRULS,                      |
|                       REPLACEPRT_TRIVIALRULS tables and populate|
|                       them for Failure Relationship analysis    |
|                       and creating ANALYSISPDFTEMPLATE table and| 
|                       populating it for export to pdf feature   |
|                       (defect S0692838)                         |
| sinsaa    13Oct2010   Defect S0666407to push the missing row in |
|                       failure relationship analysis for         |
|                       uniformlinkwidth macrovariable.           |
| sinsaa    14Oct2010   Defect S0666407 to push the changes for   |
|                       analysispdftemplate(S0707627)             |
| sinsaa    21Oct2010   Pushed changes for                        |
|                       anlformatlabel_format_nls S0692836        |     
| atbroo    26Oct2010   Pushed changes for S0712319               |
| sinnys    27Oct2010   Defect S0699347                           |
| sinsaa    27Oct2010   Included the row for graphics in Text     |
|                       analysis(S0708064)                        |
| sinsaa    28Oct2010   Pushed changes for                        |
|                       variables_format_nls S0692836             |
| atbroo    04Nov2010   Added JobFinishedCounts                   |
| sinsaa    10Nov2010   Fixed defect S0716239			  |
| sinsaa    11Nov2010   Fixed defect S0716499                     |
| sinsaa    15Nov2010   Fixed defect S0715825                     |
| sinsaa    17Nov2010   Fixed defect S0709605	  		  |
| sinsaa    10Dec2010   Fixed defect S0723809			  |
| sinsaa    14Dec2010   Fixed defect S0724522			  |
| sinsaa    16Dec2010   Fixed defect S0725574			  |
| sascis    23Jan2012   S0826550: personOMRname                   |
+-----------------------------------------------------------------+
+-----------------------------------------------------------------+
| Copyright (c) 2010 by SAS Institute Inc., Cary, NC 27513 USA    |
| ---All Rights Reserved.                                         |
+-----------------------------------------------------------------+
*/


/* -------------------------------------------------------------- */
/* Alters the Analysisoptions to                                  */
/* - Add the allowstemplates column                               */
/* - updates that column with values                              */
/* - Deleting rows associated with ei_runint                      */
/* -------------------------------------------------------------- */


        alter table &parmslLibRef..AnalysisOptions
          ADD   ALLOWSTEMPLATES char(1) label='Allows Templates?'
        ;

        update &parmslLibRef..AnalysisOptions set
                ALLOWSTEMPLATES="0"
        ;
        
        update &parmslLibRef..AnalysisOptions set
                ALLOWSTEMPLATES="1"
                where ANALYSISTYPE='DETAIL' and ANLOPTGROUPID='AVARS' and ANLOPTATTRID='AOA132'
        ;       
        
        delete from &parmslLibRef..analysisoptions
           where ANALYSISTYPE in ('EIAUTOMATED' 'EIDRILLTO') and ANLOPTATTRID='AOA91'
        ;


/* -------------------------------------------------------------- */
/* Creates a new table to store the detail templates              */
/* -------------------------------------------------------------- */            
        create table &userdlLibRef..analysis_option_templates (
                ID              CHAR(80)   NOT NULL PRIMARY KEY,
                NAME            CHAR (132),  
                AUTHOR          CHAR(200) ,
                VALUES          CHAR(8000), 
                CREATED_DT      NUMERIC format=DATETIME18.2 informat=BEST8.,
                MODIFIED_DT     NUMERIC format=DATETIME18.2 informat=BEST8.
        )
        ;
        ALTER TABLE &userdlLibRef..analysis_option_templates    MODIFY ID LABEL='Template Id';
        ALTER TABLE &userdlLibRef..analysis_option_templates    MODIFY NAME LABEL='Template Name';
        ALTER TABLE &userdlLibRef..analysis_option_templates    MODIFY AUTHOR LABEL='Created By';
        ALTER TABLE &userdlLibRef..analysis_option_templates    MODIFY VALUES LABEL='Values';
        ALTER TABLE &userdlLibRef..analysis_option_templates    MODIFY CREATED_DT LABEL='Created Date';
        ALTER TABLE &userdlLibRef..analysis_option_templates    MODIFY MODIFIED_DT LABEL='Modified Date';
        
/* -------------------------------------------------------------- */
/* Alter AnalysisTypes to                                         */
/* - Allow Reliability as Drill to                                */
/* -------------------------------------------------------------- */            
        update &parmslLibRef..AnalysisTypes_base set
               CHILDRPTCRITERIA='PARETO TREND EXPOSURE GEOGRAPHIC TRENDEXP STATDRIVER MULTIVARIATE TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS CROSSTAB FAILREL'
               where ANALYSISTYPE = 'RELIABILITY'
        ;



/* ---------------------------------------------------------------*/
/* Insert new row to Screenattrsvalues_base to                    */
/* - Allow Reliability biweibull distribution                     */
/* ---------------------------------------------------------------*/

         insert into &parmslLibRef..Screenattrsvalues_base 
                  (ATTRNAME,ORDER,VALUE,ATTRCRITERIA)
                  values ('DISTRIBUTION',4,'biweibull','')
                  
         ;         


/* ---------------------------------------------------------------*/
/* Insert new row to Screenattrsvalues_nls to                     */
/* - Allow Reliability biweibull label translation                */
/* ---------------------------------------------------------------*/

         insert into &parmslLibRef..Screenattrsvalues_nls
                  (KEY,LOCALE,LINENO,TEXT)
                 values ('DISTRIBUTION4',"&locale",1,"&a1")
         ;
                  


/* -------------------------------------------------------------- */
/* Alter UserAttributes to                                        */
/* - Add userid column                                            */
/* - Populate userid column to default to personomrname           */
/* -------------------------------------------------------------- */            

        alter table &parmslLibRef..UserAttributes
          ADD  USERID char(64) label='User ID'
        ;

/* S0826550: LOGINID was retained from the 4.1 table in the 4.2   */
/*           migration script                                     */

        select name 
          from dictionary.columns
         where upcase(libname) = upcase("&parmslLibRef.") 
           and upcase(memname) = "USERATTRIBUTES" 
           and upcase(name) = "LOGINID";
        
        %if &sqlobs GT 0 %then
        %do;
        update &parmslLibRef..UserAttributes set
               USERID=loginid;                        /* S0826550 */
        %end;
        %else do;
        update &parmslLibRef..UserAttributes set
               USERID=personOMRname;
        %end;
        


/* -------------------------------------------------------------- */
/* Insert new row to variables_base to                            */
/* - Add COSTINDEX variable                                       */
/* -------------------------------------------------------------- */

        select max(input(substr(variableid,2),best12.))+1 into :l_newvariableid
           from &parmslLibRef..variables_base
        ;
        
        %let l_newvariableid=V%left(&l_newvariableid);
        %put l_newvariableid="&l_newvariableid";
        
        insert into &parmslLibRef..variables_base
           set variableid="&l_newvariableid",datatype='C',
           name='COSTINDEX',source='EICV',type='N',dsdsvariable='0'
        ;
    
    
/* -------------------------------------------------------------- */
/* Insert new row to variables_label_nls to                       */
/* - Add COSTINDEX label for translation                          */
/* -------------------------------------------------------------- */  

        insert into &parmslLibRef..variables_label_nls
           (LOCALE,KEY,LINENO,TEXT)
           values("&locale","&l_newvariableid",1,"&a2") 
        ;
 
 
/* -------------------------------------------------------------- */
/* Insert new row to variables_format_nls to                      */
/* - Add COSTINDEX format for translation                         */
/* -------------------------------------------------------------- */  

        insert into &parmslLibRef..variables_format_nls
           (LOCALE,KEY,LINENO,TEXT)
           values("&locale","&l_newvariableid",1,'NLNUM16.3')
        ;
        
        
/* -------------------------------------------------------------- */
/* Updates to ANLFORMATLABEL_xxxx Tables                          */
/* - Deleting rows that have been moved to VARIABLES table        */
/* -------------------------------------------------------------- */

        select key into :l_key
           from &parmslLibRef..anlformatlabel_base
           where upcase(varname)='COSTINDEX'
        ;
        
        %put l_key=&l_key;
        
        delete from &parmslLibRef..anlformatlabel_base
           where key="&l_key"
        ;
        
        delete from &parmslLibRef..anlformatlabel_format_nls
           where key="&l_key"
        ;
        
        delete from &parmslLibRef..anlformatlabel_label_nls
           where key="&l_key"
        ;


/* -------------------------------------------------------------- */
/* Remove ei_runint from EIAUTORUNGROUPS table                    */
/* -------------------------------------------------------------- */

        alter table &parmslLibRef..eiautorungroups
           drop ei_runint
        ;


/* -------------------------------------------------------------- */
/* Updates to ANALYSISOPTIONATTRIBUTES_xxxx Tables                */
/* - Deleting rows associated with ei_runint                      */
/* -------------------------------------------------------------- */

        delete from &parmslLibRef..analysisoptionattributes_base
           where ANLOPTATTRID='AOA91'
        ;
        
        delete from &parmslLibRef..analysisoptionattributes_nls
           where key='AOA91'
        ;


/* ---------------------------------------------------------------*/
/* Insert new rows into eiautoparms to                            */
/* - Add destartdate - column in lookup tables that holds the     */
/*   introduction date                                            */
/* - Add einorecalc - allow control of when claim rates and       */
/*   seasonal values are recalculated                             */
/* ---------------------------------------------------------------*/

        insert into &parmslLibRef..eiautoparms 
           set datasourceid='1',eipg_id=0,macrovar='DESTARTDATE',
           macrostmt='',type='H'                
        ; 
        insert into &parmslLibRef..eiautoparms
           set datasourceid='1',eipg_id=0,macrovar='EINORECALC',
           macrostmt='1',type='H'
        ;
  
  /* -------------------------------------------------------------- */
  /* Updates to MODULESDEFINITION Table                             */
  /* - Adding rows                                                  */
  /* - adding rows for S0585374 (EI drill-to threshold)             */
  /* -------------------------------------------------------------- */
  
        insert into &parmslLibRef..MODULESDEFINITION
                (MODULENAME,MODULECONTROLLER)
                values ('UTIL_GETEIANALYSISIDS','%util_getEIanalysisIDs')
        ;

  /* for export to excel */
        insert into &parmslLibRef..MODULESDEFINITION
                (MODULENAME,MODULECONTROLLER)
                values ('ANL_EXPORTEXCEL','%anl_exportexcel')
        ;

  /* for export to pdf */       
        insert into &parmslLibRef..MODULESDEFINITION
                        (MODULENAME,MODULECONTROLLER)
                        values ('ANL_EXPORTPDF','%anl_exportpdf')
                ;
                
  /* for EI drill-to threshold */
        insert into &parmslLibRef..modulesdefinition
           set modulename='UTIL_EIDRILLTO_THRESHOLD',
           modulecontroller='%util_eidrillto_threshold'
           ;

  /* for Performance improvements to CreateAOXML - S0700242*/
        insert into &parmslLibRef..MODULESDEFINITION
                (MODULENAME,MODULECONTROLLER)
                values ('UTIL_STANDARDDS','%util_standardds')
        ;


  /* -------------------------------------------------------------- */
  /* Deleting rows from PARMSL.ANALYSISMACVARS Table                */
  /* -  for  Combine Pareto / EI threshold  requirment              */
  /* -------------------------------------------------------------- */
  
  
   delete from &parmsllibref..Analysismacvars
    where ANALYSISTYPE eq "PARETO" and upcase(MACROVAR) eq "MAXNUMBARS"
    ;
  
  delete from &parmsllibref..Analysismacvars
    where ANALYSISTYPE eq "EITHRESHOLD" and upcase(MACROVAR) eq "MAXNUMBARS"
  ;
  
   /* -------------------------------------------------------------- */
    /* Updates the Analysistypes_base Table                             */
    /* - Changing the value of DATAPREPMACRO col for EITHRESHOLD analysis*/
    /*   for  Combine Pareto / EI threshold  requirment            */  
  /* -------------------------------------------------------------- */
  
  update &parmsllibref..Analysistypes_base
       set DATAPREPMACRO='anl_paretoDataPrep'
         where ANALYSISTYPE eq 'EITHRESHOLD'
         ;

   /* -------------------------------------------------------------- */
   /* Updates the Analysistypes_base Table for S0585374              */
   /* - adding rows for THRESHOLD                                    */ 
   /* -------------------------------------------------------------- */
 
        insert into &parmslLibRef..analysistypes_base
           set analysistype ='THRESHOLD',
               securitylevel = 'user',
               order = 165,
               dataprepmacro = 'anl_paretoDataPrep',
               outputmacro = 'anl_eithresholdOutput',
               CHILDRPTCRITERIA = 'PARETO TREND EXPOSURE GEOGRAPHIC TRENDEXP STATDRIVER
                  MULTIVARIATE TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS CROSSTAB FAILREL',
                RPTGROUP = 'EIDRILLTO'
           ;
           
   /* -------------------------------------------------------------- */
   /* Updates the Analysistypes_nls Table for S0585374               */
   /* - adding rows for THRESHOLD                                    */ 
   /* -------------------------------------------------------------- */
   
        insert into &parmslLibRef..analysistypes_nls
           set key ='THRESHOLD',
               locale = "&locale",
               lineno = 1,
               text = "&a10"
           ;
           
        /* -------------------------------------------------------------- */
        /* Creates a new table security_options for column level security */
        /* -------------------------------------------------------------- */            
          
        create table &parmslLibRef..security_options (
                IS_ENABLED              CHAR(1) ,
                PATH                    CHAR (256)  
        )
        ;
        ALTER TABLE &parmslLibRef..security_options    MODIFY IS_ENABLED LABEL='Is Security Enabled';
        ALTER TABLE &parmslLibRef..security_options    MODIFY PATH LABEL='Infomap path';

          
 /* -------------------------------------------------------------- */
  /* Insert new rows into PARMSL.ANALYSISMACVARS Table              */
  /* -  for Summary Tables requirment                                */
  /* -------------------------------------------------------------- */
  
  insert into &parmslLibRef..Analysismacvars
         (ANALYSISTYPE, MACROVAR, MACROSTMT)
        values ('CROSSTAB', 'otherFormatLabelCriteria', 'TRUE')
        values ('CROSSTAB', 'uniqueValue', 'TRUE')
        values ('CROSSTAB', 'findExpMeasurement', 'TRUE')
        values ('CROSSTAB', 'maxByVar', '10000')
        values ('CROSSTAB', 'byvarlimit', '50')
        values ('CROSSTAB', 'claimDrillVar', '')
        values ('CROSSTAB', 'productDrillVar', '')
          ;
 /* -------------------------------------------------------------- */
  /* Insert new rows into PARMSL.analysisoptionattributes_base Table */
  /* -  for Summary Tables requirment                                */
  /* -------------------------------------------------------------- */    
  
  insert into &parmslLibRef..analysisoptionattributes_base
         (ANLOPTATTRID, NAME, INPUTFIELDTYPE, ISRANGE, FORMATREGEX, SIGN, ALLOWZERO, MIN, MAX, PRECISION, DATETYPE, DATESTYLEPATTERN, INPUTFIELDSOURCE, INPUTFIELDTABLELIBRARY, INPUTFIELDTABLENAME, INPUTFIELDTABLEWHERE, 
          INPUTFIELDTABLENUMROWS, INPUTFIELDVALUECOLUMN, INPUTFIELDLABELCOLUMN, MINSELECT, MAXSELECT, INTERACTIONXML)
        values ('AOA161', 'reportVarID', 'FreeTextDataType', '', '', '', '', ., ., ., '', '', 'as_screenvariables(p_attrname=reportVar,p_sql=as_sql_asvariables(p_varUsage=reportvar))', '', '', '', ., '', '', 1, 3, '')
        values ('AOA162', 'analysisVarID', 'FreeTextDataType', '', '', '', '', ., ., ., '', '', 'as_screenvariables(p_attrname=analysisVar,p_sql=as_sql_asvariables(p_varUsage=analysisvar))', '', '', '', ., '', '', 1, 1, '')
        values ('AOA163', 'exposureType', 'FreeTextDataType', '', '', '', '', ., ., ., '', '', '', 'PARMSL', 'SCREENATTRSVALUES', "upcase(ATTRNAME)='EXPOSURETYPE'", 2, 'VALUE', 'LABEL', 1, 1, 'analysisSetup.xml')
        values ('AOA164', 'expcharttype', 'FreeTextDataType', '', '', '', '', ., ., ., '', '', '', 'PARMSL', 'SCREENATTRSVALUES', "upcase(ATTRNAME)='EXPCHARTTYPE'", 2, 'VALUE', 'LABEL', 1, 1, 'analysisSetup.xml')
          ;
 /* -------------------------------------------------------------- */
  /* Insert new rows into PARMSL.analysisoptionattributes_nls Table */
  /* -  for Summary Tables requirment                                */
  /* -------------------------------------------------------------- */    
  
  insert into &parmslLibRef..analysisoptionattributes_nls
                        (key, LOCALE, LINENO, TEXT)
        values ('AOA161', "&locale", 1, "&a3")
        values ('AOA162', "&locale", 1, "&a4")
        values ('AOA163', "&locale", 1, "&a5")
        values ('AOA164', "&locale", 1, "&a6")
        ;
        
 /* -------------------------------------------------------------- */
  /* Insert new rows into PARMSL.analysisoptions Table */
  /* -  for Summary Tables requirment                                */
  /* -------------------------------------------------------------- */    
  insert into &parmslLibRef..analysisoptions
          (WARRANTYTYPE,ANALYSISTYPE,ANLOPTGROUPID,ANLOPTATTRID,PEERNUMBER,ISREQUIRED,ALLOWDEFAULTVALUE,DEFAULTVALUE,ALLOWSTEMPLATES)
        values("2","CROSSTAB","AVARS","AOA45",1,"1","1","C","0")
        values("2","CROSSTAB","AVARS","AOA161",2,"0","1","","0")
        values("2","CROSSTAB","AVARS","AOA162",3,"1","1","","0")
        values("2","CROSSTAB","ANAL","AOA163",1,"0","1","","0")
        values("2","CROSSTAB","ANAL","AOA30",2,"1","1","asis","0")
        values("2","CROSSTAB","ANAL","AOA5",3,"1","0","","0")
        values("2","CROSSTAB","ANAL","AOA8",4,"0","0","","0")
        values("2","CROSSTAB","ANAL","AOA31",5,"1","1","all","0")
        values("2","CROSSTAB","ANAL","AOA40",6,"1","0","","0")
        values("2","CROSSTAB","ANAL","AOA95",7,"1","0","","0")
        values("2","CROSSTAB","ANAL","AOA164",8,"1","1","cumulative","0")
        values("2","CROSSTAB","FLTR","AOA33",1,"0","1","","0")
        values("2","CROSSTAB","FLTR","AOA34",2,"0","1","","0")
        values("2","CROSSTAB","FLTR","AOA9",3,"1","1","TRUE","0")
        values("2","CROSSTAB","FLTR","AOA20",4,"0","1","","0")
        values("2","CROSSTAB","FLTR","AOA21",5,"0","0","","0")
        
        ;
  /* -------------------------------------------------------------- */
  /* Insert new rows into PARMSL.analysistypes_base Table           */
  /* -  for Summary Tables requirment                               */
  /* -------------------------------------------------------------- */  
  
   insert into &parmslLibRef..analysistypes_base
         (ANALYSISTYPE,SECURITYLEVEL,ORDER,DATAPREPMACRO,OUTPUTMACRO,CHILDRPTCRITERIA,RPTGROUP)
                values ('CROSSTAB','user',200,'anl_crosstabDataPrep','anl_crosstaboutput',
                'PARETO TREND GEOGRAPHIC EXPOSURE TRENDEXP TIMEOFCLAIM EITHRESHOLD CROSSTAB FAILREL','MAIN')
               ;

  /* -------------------------------------------------------------- */
  /* Modify rows into PARMSL.analysistypes_base Table               */
  /* -  for Summary Tables requirment (defect S0686719)             */
  /* (RELIABILITY handled in code for drill-to above)               */
  /* -------------------------------------------------------------- */
 
        update &parmslLibRef..AnalysisTypes_base set
                CHILDRPTCRITERIA='PARETO TREND TRENDEXP EXPOSURE GEOGRAPHIC STATDRIVER MULTIVARIATE TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS CROSSTAB FAILREL'
                where ANALYSISTYPE = 'DETAIL'
        ;
        
        update &parmslLibRef..AnalysisTypes_base set
                CHILDRPTCRITERIA='PARETO TREND TRENDEXP EXPOSURE GEOGRAPHIC STATDRIVER MULTIVARIATE TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS CROSSTAB FAILREL'
                where ANALYSISTYPE = 'EXPOSURE'
        ;
        
        update &parmslLibRef..AnalysisTypes_base set
                CHILDRPTCRITERIA='PARETO TREND EXPOSURE TRENDEXP STATDRIVER MULTIVARIATE TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS FAILREL CROSSTAB FAILREL'
                where ANALYSISTYPE = 'GEOGRAPHIC'
        ;
        
        update &parmslLibRef..AnalysisTypes_base set
                CHILDRPTCRITERIA='PARETO TREND EXPOSURE GEOGRAPHIC STATDRIVER MULTIVARIATE TRENDEXP TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS CROSSTAB FAILREL'
                where ANALYSISTYPE = 'MULTIVARIATE'
        ;
        
        update &parmslLibRef..AnalysisTypes_base set
                CHILDRPTCRITERIA='PARETO TREND EXPOSURE GEOGRAPHIC TRENDEXP STATDRIVER MULTIVARIATE TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS CROSSTAB FAILREL'
                where ANALYSISTYPE = 'PARETO'
        ;
  
        update &parmslLibRef..AnalysisTypes_base set
                CHILDRPTCRITERIA='PARETO TREND EXPOSURE GEOGRAPHIC STATDRIVER MULTIVARIATE TRENDEXP TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS CROSSTAB FAILREL'
                where ANALYSISTYPE = 'STATDRIVER'
        ;  
        
        update &parmslLibRef..AnalysisTypes_base set
                CHILDRPTCRITERIA='PARETO EXPOSURE TREND TRENDEXP TIMEOFCLAIM GEOGRAPHIC EITHRESHOLD TEXTANALYSIS CROSSTAB FAILREL'
                where ANALYSISTYPE = 'TIMEOFCLAIM'
        ; 
        
        update &parmslLibRef..AnalysisTypes_base set
                CHILDRPTCRITERIA='PARETO TREND TRENDEXP EXPOSURE GEOGRAPHIC STATDRIVER MULTIVARIATE TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS CROSSTAB FAILREL'
                where ANALYSISTYPE = 'TREND'
        ; 

        update &parmslLibRef..AnalysisTypes_base set
                CHILDRPTCRITERIA='PARETO TREND GEOGRAPHIC EXPOSURE TRENDEXP TIMEOFCLAIM EITHRESHOLD CROSSTAB FAILREL'
                where ANALYSISTYPE = 'TRENDEXP'
        ; 
        
        update &parmslLibRef..AnalysisTypes_base set
                CHILDRPTCRITERIA='PARETO TREND TRENDEXP EXPOSURE GEOGRAPHIC STATDRIVER MULTIVARIATE TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS CROSSTAB'
                where ANALYSISTYPE = 'EIDRILLTO'
        ; 

        update &parmslLibRef..AnalysisTypes_base set
                CHILDRPTCRITERIA='PARETO TREND TRENDEXP EXPOSURE GEOGRAPHIC STATDRIVER MULTIVARIATE TIMEOFCLAIM FORECASTING EITHRESHOLD CROSSTAB TEXTANALYSIS'
                where ANALYSISTYPE = 'EIDRILLTOA'
        ;

 
 /* -------------------------------------------------------------- */
  /* Insert new rows into PARMSL.analysistypes_nls Table */
  /* -  for Summary Tables requirment                                */
  /* -------------------------------------------------------------- */  
  
  insert into &parmslLibRef..analysistypes_nls
        (key,LOCALE,LINENO,TEXT)
        values ('CROSSTAB',"&locale",1,"&a7")
         ;

 
/* -------------------------------------------------------------- */
  /* Insert new rows into PARMSL.anlformatlabel_base Table */
  /* -  for Summary Tables requirment                                */
  /* -------------------------------------------------------------- */
  
        insert into &parmslLibRef..anlformatlabel_base
               (KEY,VARNAME,OTHERCRITERIAVAR1,OTHERCRITERIAVALUE1,DEFAULT)
        values ('A293','TIMEINSERVICE_new','','','')
        values ('A294','BINMILEAGE_new','','','')
        ;
        
 /* -------------------------------------------------------------- */
   /* Insert new rows into PARMSL.anlformatlabel_label_nls */
   /* -  for Summary Tables requirment                                */
   /* -------------------------------------------------------------- */
   
        insert into &parmslLibRef..anlformatlabel_label_nls
               (KEY,LOCALE,LINENO,TEXT)
          values ('A293',"&locale",1,"&a8")
          values ('A294',"&locale",1,"&a9")
        ;
        
        
        
        /* ---------------------------------------------------------------*/
        /* Insert new row to Parmsl.Analysistypes_base Table              */
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
        
         insert into &parmsllibref..Analysistypes_base
         (ANALYSISTYPE,SECURITYLEVEL,ORDER,DATAPREPMACRO,OUTPUTMACRO,CHILDRPTCRITERIA,RPTGROUP)
          values ('FAILREL','user',190,'anl_failRelDataPrep','anl_failRelOutput',
                  'PARETO TREND EXPOSURE GEOGRAPHIC TRENDEXP STATDRIVER MULTIVARIATE TIMEOFCLAIM FORECASTING EITHRESHOLD TEXTANALYSIS CROSSTAB FAILREL' ,'MAIN')
          ;
        
         /* ---------------------------------------------------------------*/
        /* Insert new row to Parmsl.Analysistypes_nls Table              */
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
           insert into &parmsllibref..Analysistypes_nls
           (KEY,LOCALE,LINENO,TEXT)
            values ('FAILREL',"&locale",1,"&F0")
                ;
        
        
        /* ---------------------------------------------------------------*/
        /* Creating a new table Parmsl.failreltable                       */
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
         create table &parmslLibRef..failreltable (label='Failure Relationship Metadata')
            (
               TARGETVAR char(32) label="Target Variable",
               SEQVAR char(32) label="Sequence Variable",
               IDVAR char(32) label="ID Variable",
               COSTVAR char(32) label="Cost Variable",
               ASSOCVAR char(32) label="ID Var for Association Analysis",
               TRIVIALRULESDS char(32) label="Trivial rules dataset name",
               SAMEVAL char(32) label="Same option value of Proc Sequence",
               TARGETVARTHRESHOLD num(8) format best12. label="Target Var Threshold"
            )
           ;
        
     
        /* ---------------------------------------------------------------*/
        /* Updating table Parmsl.Validbin_base                            */
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
        
                 update &parmsllibref..Validbin_base
                 set BINDISPLAY="MAXEXPVAL MATURITYLEVEL TISBINSTODISPLAY FAILREL"
                 where BINPRODUCT in ('0','1','2','3','4','5','6','7','8','9','10','11','18')
                 ;
        
                 update &parmsllibref..Validbin_base
                 set BINDISPLAY="MAXEXPVAL MATURITYLEVEL RELIABILITY TISBINSTODISPLAY FAILREL"
                 where BINPRODUCT in ('12','24')
                 ;
        
                 
        /* ---------------------------------------------------------------*/
        /* Insert new row to Parmsl.Modulesdefinition Table                      */
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
                 insert into &parmsllibref..Modulesdefinition
                 (MODULENAME,MODULECONTROLLER)
                 values('CREATEFAILRELTRENDCHART','%anl_failreltrendchart')
                 ;
        
      
        /* ---------------------------------------------------------------*/
        /* Insert new rows in to Parmsl.Screenattrsvalues_base Table         */
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
                 insert into &parmsllibref..Screenattrsvalues_base
                  (ATTRNAME,ORDER,VALUE,ATTRCRITERIA)
              values ('TARGETVAR',10,'LABOR_CD','')
              values ('TARGETVAR',20,'REPLACED_MATERIAL_ID','')
              values ('APPLYINTOCTIMEINCR',10,'TRUE','')  
              values ('APPLYINTOCTIMEINCR',20,'FALSE','')
              values ('APPLYRULESTCRITERIA',10,'TRUE','')
              values ('APPLYRULESTCRITERIA',20,'FALSE','') 
              values ('SUPPORTVALPERCENT',10,'0.01','') 
              values ('SUPPORTVALPERCENT',20,'0.1','') 
              values ('SUPPORTVALPERCENT',30,'1.0','') 
              values ('SUPPORTVALPERCENT',40,'2.0','') 
              values ('SUPPORTVALPERCENT',50,'3.0','') 
              values ('SUPPORTVALPERCENT',60,'4.0','')       
              values ('SUPPORTVALPERCENT',70,'5.0','') 
              values ('SUPPORTVALPERCENT',80,'6.0','') 
              values ('SUPPORTVALPERCENT',90,'7.0','') 
              values ('SUPPORTVALPERCENT',100,'8.0','') 
              values ('SUPPORTVALPERCENT',110,'9.0','') 
              values ('SUPPORTVALPERCENT',120,'10.0','') 
              values ('SUPPORTVALPERCENT',130,'20.0','') 
              values ('SUPPORTVALPERCENT',140,'30.0','') 
              values ('SUPPORTVALPERCENT',150,'40.0','') 
              values ('SUPPORTVALPERCENT',160,'50.0','') 
              values ('SUPPORTVALPERCENT',170,'60.0','') 
              values ('SUPPORTVALPERCENT',180,'70.0','') 
              values ('SUPPORTVALPERCENT',190,'80.0','') 
              values ('CONFVALPERCENT',10,'1.0','') 
              values ('CONFVALPERCENT',20,'2.0','') 
              values ('CONFVALPERCENT',30,'3.0','') 
              values ('CONFVALPERCENT',40,'4.0','') 
              values ('CONFVALPERCENT',50,'5.0','') 
              values ('CONFVALPERCENT',60,'6.0','') 
              values ('CONFVALPERCENT',70,'7.0','') 
              values ('CONFVALPERCENT',80,'8.0','') 
              values ('CONFVALPERCENT',90,'9.0','') 
              values ('CONFVALPERCENT',100,'10.0','') 
              values ('CONFVALPERCENT',110,'20.0','') 
              values ('CONFVALPERCENT',120,'30.0','') 
              values ('CONFVALPERCENT',130,'40.0','') 
              values ('CONFVALPERCENT',140,'50.0','') 
              values ('CONFVALPERCENT',150,'60.0','') 
              values ('CONFVALPERCENT',160,'70.0','') 
              values ('CONFVALPERCENT',170,'80.0','') 
              values ('RULETYPE',10,'TYPE1','') 
              values ('RULETYPE',20,'TYPE2','') 
              values ('RULETYPE',30,'TYPE3','') 
              values ('RULETYPE',40,'TYPE4','') 
              values ('RULESIZE',10,'1-1','') 
              values ('RULESIZE',20,'1-2','') 
              values ('RULESIZE',30,'2-1','') 
              values ('RULESIZE',40,'2-2','') 
                 ;
        
                 
        /* ---------------------------------------------------------------*/
        /* Insert new row to Parmsl.Screenattrsvalues_nls Table           */
        /* -  for Failure Relation Ship analysis                          */
        /* ---------------------------------------------------------------*/
        
              insert into &parmslLibRef..Screenattrsvalues_nls
              (KEY,LOCALE,LINENO,TEXT)
        
              values ('TARGETVAR10',"&locale",1,"&F1")
              values ('TARGETVAR20',"&locale",1,"&F2")
              values ('APPLYINTOCTIMEINCR10',"&locale",1,"&F3")
              values ('APPLYINTOCTIMEINCR20',"&locale",1,"&F4")
              values ('APPLYRULESTCRITERIA10',"&locale",1,"&F3")
              values ('APPLYRULESTCRITERIA20',"&locale",1,"&F4")
              values ('SUPPORTVALPERCENT10',"&locale",1,"&F5")
              values ('SUPPORTVALPERCENT20',"&locale",1,"&F6")
              values ('SUPPORTVALPERCENT30',"&locale",1,"&F7")
              values ('SUPPORTVALPERCENT40',"&locale",1,"&F8")
              values ('SUPPORTVALPERCENT50',"&locale",1,"&F9")
              values ('SUPPORTVALPERCENT60',"&locale",1,"&F10")
              values ('SUPPORTVALPERCENT70',"&locale",1,"&F11")
              values ('SUPPORTVALPERCENT80',"&locale",1,"&F12")
              values ('SUPPORTVALPERCENT90',"&locale",1,"&F13")
              values ('SUPPORTVALPERCENT100',"&locale",1,"&F14")
              values ('SUPPORTVALPERCENT110',"&locale",1,"&F15")
              values ('SUPPORTVALPERCENT120',"&locale",1,"&F16")
              values ('SUPPORTVALPERCENT130',"&locale",1,"&F17")
              values ('SUPPORTVALPERCENT140',"&locale",1,"&F18")
              values ('SUPPORTVALPERCENT150',"&locale",1,"&F19")
              values ('SUPPORTVALPERCENT160',"&locale",1,"&F20")
              values ('SUPPORTVALPERCENT170',"&locale",1,"&F21")
              values ('SUPPORTVALPERCENT180',"&locale",1,"&F22")
              values ('SUPPORTVALPERCENT190',"&locale",1,"&F23")
              values ('CONFVALPERCENT10',"&locale",1,"&F7")
              values ('CONFVALPERCENT20',"&locale",1,"&F8")
              values ('CONFVALPERCENT30',"&locale",1,"&F9")
              values ('CONFVALPERCENT40',"&locale",1,"&F10")
              values ('CONFVALPERCENT50',"&locale",1,"&F11")
              values ('CONFVALPERCENT60',"&locale",1,"&F12")
              values ('CONFVALPERCENT70',"&locale",1,"&F13")
              values ('CONFVALPERCENT80',"&locale",1,"&F14")
              values ('CONFVALPERCENT90',"&locale",1,"&F15")
              values ('CONFVALPERCENT100',"&locale",1,"&F16")
              values ('CONFVALPERCENT110',"&locale",1,"&F17")
              values ('CONFVALPERCENT120',"&locale",1,"&F18")
              values ('CONFVALPERCENT130',"&locale",1,"&F19")
              values ('CONFVALPERCENT140',"&locale",1,"&F20")
              values ('CONFVALPERCENT150',"&locale",1,"&F21")
              values ('CONFVALPERCENT160',"&locale",1,"&F22")
              values ('CONFVALPERCENT170',"&locale",1,"&F23")
              values ('RULETYPE10',"&locale",1,"&F24")
              values ('RULETYPE20',"&locale",1,"&F25")
              values ('RULETYPE30',"&locale",1,"&F26")
              values ('RULETYPE40',"&locale",1,"&F59")
              values ('RULESIZE10',"&locale",1,"&F60")
              values ('RULESIZE20',"&locale",1,"&F61")
              values ('RULESIZE30',"&locale",1,"&F62")
              values ('RULESIZE40',"&locale",1,"&F63")
              
             ;
        /* ---------------------------------------------------------------*/
        /* Insert new rows in to Parmsl.Analysismacvars Table         */
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
                 insert into &parmsllibref..Analysismacvars
             (ANALYSISTYPE,MACROVAR,MACROSTMT)
              values ('FAILREL','minItems','2')
              values ('FAILREL','binLength','30')
              values ('FAILREL','xvar1','iotIncr')
              values ('FAILREL','yvar1','SUPPORT')
              values ('FAILREL','xvar2','iotIncr')
              values ('FAILREL','yvar2','CONF')
              values ('FAILREL','ruleFilterCriteria','support')
              values ('FAILREL','oneTrvRuleDSFlag','0')
              values ('FAILREL','ruleThresoldValue','12000')
              values ('FAILREL','linkWidthVariable','count' )
              values ('FAILREL','linkValueVariable','conf' )
              values ('FAILREL','maxLinkWidth','3')
              values ('FAILREL','nColorRegular','#FF0000')
              values ('FAILREL','nColorSpecial','#66CC00')
              values ('FAILREL','nodeShape1','1')
              values ('FAILREL','nodeShape2','2')
              values ('FAILREL','chartScalingFactor','400')
              values ('FAILREL','sasfile','1')
              values ('FAILREL','testmode','0')
              values ('FAILREL','otherFormatLabelCriteria','FALSE')
              values ('FAILREL','dmdbmaxlev','100001')
              values ('FAILREL','minConfPAssoc','1.0')
              values ('FAILREL','nodeTip','CODE')
              values ('FAILREL','linkTip','DESC')
              values ('FAILREL','nodeSize','UNIFORM')
              values ('FAILREL','linkWidth','UNIFORM')
              values ('FAILREL','uniformLinkWidth','1')
              values ('FAILREL','nodeSizeVariable','count')
              values ('FAILREL','thresholdSliderVariable','CONF')
              values ('FAILREL','thresholdSliderScaleType','PERCENTILE')
              values ('FAILREL','xmlProlog1','<Data version="9.2M3">')
              values ('FAILREL','truleEndStartFlag','ALL')
              values ('FAILREL','assocTableThreshold','100')
              values ('FAILREL','maxLinkNumber','2000')
              values ('FAILREL','maxNodeNumber','300')
              values ('FAILREL','seqProcThreshold','301')
              ;
             
        
        /* ---------------------------------------------------------------*/
        /* Insert new rows in to Parmsl.Analysisoptions Table         */
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
                  insert into &parmsllibref..Analysisoptions
                  (WARRANTYTYPE,ANALYSISTYPE,ANLOPTGROUPID,ANLOPTATTRID,PEERNUMBER,ISREQUIRED,ALLOWDEFAULTVALUE,DEFAULTVALUE,ALLOWSTEMPLATES)
                    values ('2','FAILREL','AVARS','AOA144',1,'1','1','','0')
                    values ('2','FAILREL','AVARS','AOA158',2,'1','1','FALSE','0')
                    values ('2','FAILREL','AVARS','AOA159',4,'1','1','TYPE1','0')
                    values ('2','FAILREL','AVARS','AOA146',5,'0','0','','0')
                    values ('2','FAILREL','AVARS','AOA147',6,'0','0','FALSE','0')
                    values ('2','FAILREL','ANAL','AOA148',1,'1','1','2','0')
                    values ('2','FAILREL','ANAL','AOA149',2,'1','0','FALSE','0')
                    values ('2','FAILREL','ANAL','AOA165',3,'1','1','1-1','0')
                    values ('2','FAILREL','ANAL','AOA150',4,'1','1','TRUE','0')
                    values ('2','FAILREL','ANAL','AOA156',5,'1','1','percent','0')
                    values ('2','FAILREL','ANAL','AOA151',6,'0','1','0.1','0')
                    values ('2','FAILREL','ANAL','AOA157',7,'0','0','','0')
                    values ('2','FAILREL','ANAL','AOA152',8,'0','1','1.0','0')
                    values ('2','FAILREL','ANAL','AOA153',9,'0','1','1','0')
                    values ('2','FAILREL','ANAL','AOA154',10,'0','1','100','0')
                    values ('2','FAILREL','ANAL','AOA155',11,'0','1','50','0')
                    values ('2','FAILREL','FLTR','AOA4',1,'0','1','','0')
                    values ('2','FAILREL','FLTR','AOA8',2,'0','1','','0')
                    values ('2','FAILREL','FLTR','AOA9',3,'1','1','TRUE','0')
                    values ('2','FAILREL','FLTR','AOA33',4,'0','1','','0')
                    values ('2','FAILREL','FLTR','AOA34',5,'0','1','','0')
                  ;
        
        /* ---------------------------------------------------------------*/
        /* Insert new rows in to Parmsl.Analysisoptionattributes_base Table*/
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
                  insert into &parmsllibref..Analysisoptionattributes_base
                  (ANLOPTATTRID,NAME,INPUTFIELDTYPE,ISRANGE,FORMATREGEX,SIGN,ALLOWZERO,MIN,MAX,PRECISION,DATETYPE,DATESTYLEPATTERN,
                  INPUTFIELDSOURCE,INPUTFIELDTABLELIBRARY,INPUTFIELDTABLENAME,INPUTFIELDTABLEWHERE,INPUTFIELDTABLENUMROWS,INPUTFIELDVALUECOLUMN,
                  INPUTFIELDLABELCOLUMN,MINSELECT,MAXSELECT,INTERACTIONXML)
              values ('AOA144','reportVarID','FreeTextDataType','','','','',.,.,.,'','',"as_screenvariables(p_attrname=reportVar,p_sql=as_sql_asvariables(p_varUsage=reportvar))",'','','',.,'','',1,1,'')
              values ('AOA146','rv_Labor_CD','FreeTextDataType','','','','',.,.,.,'','','','SWADMREF','LABOR_CODE_V','',100,'LABOR_CD','LABOR_CODE_DESC',1,25,'')
              values ('AOA147','rv_replaced_material_ID','FreeTextDataType','','','','',.,.,.,'','','','SWADMREF','REPLACED_MATERIAL_V','',10000,'MATERIAL_ID','MATERIAL_NM',1,25,'')
              values ('AOA148','maxInterOcTime','FreeTextDataType','','','','1',.,.,.,'','','','PARMSL','VALIDBIN',"upcase(BINDISPLAY) contains 'FAILREL'",15,'BINPRODUCT','BINPRODUCTDESC',1,1,'')
              values ('AOA149','applyIntOcTimeIncr','FreeTextDataType','','','','',.,.,.,'','','','PARMSL',"SCREENATTRSVALUES","upcase(ATTRNAME)='APPLYINTOCTIMEINCR'",2,'VALUE','LABEL',1,1,'')
              values ('AOA150','applyRuleStCriteria','FreeTextDataType','','','','',.,.,.,'','','','PARMSL',"SCREENATTRSVALUES","upcase(ATTRNAME)='APPLYRULESTCRITERIA'",2,'VALUE','LABEL',1,1,'')
              values ('AOA151','minSupportP','DecimalDataType','','','','',.,.,2,'','','','PARMSL',"SCREENATTRSVALUES","upcase(ATTRNAME)='SUPPORTVALPERCENT'",19,'VALUE','LABEL',1,1,'')
              values ('AOA152','minConfP','DecimalDataType','','','','',.,.,2,'','','','PARMSL',"SCREENATTRSVALUES","upcase(ATTRNAME)='CONFVALPERCENT'",17,'VALUE','LABEL',1,1,'')
              values ('AOA153','minLift','DecimalDataType','','','','1',0.5,.,.,'','','','','','',.,'','',1,1,'')
              values ('AOA154','minCost','IntegerDataType','','','','1',0,.,.,'','','','','','',.,'','',1,1,'')
              values ('AOA155','noRulesToDisplay','IntegerDataType','','','','',10,2000,.,'','','','','','',.,'','',1,1,'')
              values ('AOA156','minSupportType','FreeTextDataType','','','','',.,.,.,'','','','PARMSL',"SCREENATTRSVALUES","upcase(ATTRNAME)='MINSAMPLESIZETYPE'",2,'VALUE','LABEL',1,1,'analysisSetup.xml')
              values ('AOA157','minSupportC','DecimalDataType','','','','1',10,.,.,'','','','','','',.,'','',1,1,'')
              values ('AOA158','performRepeatRepair','FreeTextDataType','','','','',.,.,.,'','','','PARMSL',"SCREENATTRSVALUES","upcase(ATTRNAME)='APPLYINTOCTIMEINCR'",2,'VALUE','LABEL',1,1,'analysisSetup.xml')
              values ('AOA159','ruleType','FreeTextDataType','','','','',.,.,.,'','','','PARMSL',"SCREENATTRSVALUES","upcase(ATTRNAME)='RULETYPE'",4,'VALUE','LABEL',1,1,'analysisSetup.xml')
              values ('AOA165','rulesize','FreeTextDataType','','','','',.,.,.,'','','','PARMSL',"SCREENATTRSVALUES","upcase(ATTRNAME)='RULESIZE'",4,'VALUE','LABEL',1,4,'')
              ;
        
                  
        /* ---------------------------------------------------------------*/
        /* Insert new rows in to Parmsl.Analysisoptionattributes_nls Table*/
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
        
               insert into &parmsllibref..Analysisoptionattributes_nls
                    (KEY,LOCALE,LINENO,TEXT)
              values ('AOA144',"&locale",1,"&F27")
              values ('AOA146',"&locale",1,"&F29")
              values ('AOA147',"&locale",1,"&F30")
              values ('AOA148',"&locale",1,"&F31")
              values ('AOA149',"&locale",1,"&F32")
              values ('AOA150',"&locale",1,"&F33")
              values ('AOA151',"&locale",1,"&F34")
              values ('AOA152',"&locale",1,"&F35")
              values ('AOA153',"&locale",1,"&F36")
              values ('AOA154',"&locale",1,"&F37")
              values ('AOA155',"&locale",1,"&F38")
              values ('AOA156',"&locale",1,"&F39")
              values ('AOA157',"&locale",1,"&F40")
              values ('AOA158',"&locale",1,"&F41")
              values ('AOA159',"&locale",1,"&F42")
              values ('AOA165',"&locale",1,"&F45")
                  ;
        
        
        /* ---------------------------------------------------------------*/
        /* Insert new rows in to Parmsl.Anlformatlabel_base Table         */
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
        
        
               insert into &parmsllibref..Anlformatlabel_base
                  (KEY,VARNAME,OTHERCRITERIAVAR1,OTHERCRITERIAVALUE1,DEFAULT)
              values ('A277','IOTINCR','','','')
              values ('A278','RULEID','','','')
              values ('A279','RULETYPE','','','')
              values ('A280','TOTAL_RULECOST','','','')
              values ('A281','MEAN_RULECOST','','','')
              values ('A282','TOTAL_RULECOST1','','','')
              values ('A283','MEAN_RULECOST1','','','')
              values ('A284','TOTAL_RULECOST2','','','')
              values ('A285','MEAN_RULECOST2','','','')
              values ('A286','NITEMS','','','')
              values ('A287','COUNT','','','')
              values ('A288','SUPPORT','','','')
              values ('A289','CONF','','','')
              values ('A290','RULE','','','')
              values ('A291','_LHAND','','','')
              values ('A292','_RHAND','','','')
              values ('A295','RULET','','','')
                  ;
        
        /* ---------------------------------------------------------------*/
        /* Insert new rows in to Parmsl.Anlformatlabel_format_nls Table   */
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
        
              insert into &parmsllibref..Anlformatlabel_format_nls
                  (KEY,LOCALE,LINENO,TEXT)
              values ('A280',"&locale",1,'NLMNLUSD14.2')
              values ('A281',"&locale",1,'NLMNLUSD14.2')
              values ('A282',"&locale",1,'NLMNLUSD14.2')
              values ('A283',"&locale",1,'NLMNLUSD14.2')
              values ('A284',"&locale",1,'NLMNLUSD14.2')
              values ('A285',"&locale",1,'NLMNLUSD14.2')
              values ('A288',"&locale",1,'8.2')
              values ('A289',"&locale",1,'8.2')
                  ;
        
        /* ---------------------------------------------------------------*/
        /* Insert new rows in to Parmsl.Anlformatlabel_label_nls Table    */
        /* - for Failure Relation Ship analysis                           */
        /* ---------------------------------------------------------------*/
        
              insert into &parmsllibref..Anlformatlabel_label_nls
              (KEY,LOCALE,LINENO,TEXT)
              values ('A277',"&locale",1,"&F43")
              values ('A278',"&locale",1,"&F44")
              values ('A279',"&locale",1,"&F45")
              values ('A280',"&locale",1,"&F46")
              values ('A281',"&locale",1,"&F47")
              values ('A282',"&locale",1,"&F48")
              values ('A283',"&locale",1,"&F49")
              values ('A284',"&locale",1,"&F50")
              values ('A285',"&locale",1,"&F51")
              values ('A286',"&locale",1,"&F52")
              values ('A287',"&locale",1,"&F53")
              values ('A288',"&locale",1,"&F54")
              values ('A289',"&locale",1,"&F55")
              values ('A290',"&locale",1,"&F56")
              values ('A291',"&locale",1,"&F57")
              values ('A292',"&locale",1,"&F58")
              values ('A295',"&locale",1,"&F64")
                  ;
                  
                  
                  
        /* -------------------------------------------------------------- */
           /* Updates the analysismacvars Table                             */
           /* - Changing the value of MAXREPORTLEVEL col for MULTIVARIATE analysis*/
           /*   for  defect S0657609  requirment            */  
         /* -------------------------------------------------------------- */
         
         update &parmsllibref..Analysismacvars
              set MACROSTMT='50'
                 where ANALYSISTYPE eq 'MULTIVARIATE' and MACROVAR eq 'maxreportLevel'
                 and MACROSTMT eq '300'
         ;



           /* ---------------------------------------------------------------------------------------------------------------------------------*/
           
          /* Following code creates and populates the trivial rules datasets for failure relationship analysis. A separate trivial rules dataset*/
          /* is required for each reporting variable used in the analysis. For the names of the trivial rules datasets, please refer to the     */
          /* script for parmsl.failreltable dataset. The structure of these datasets is same for different reporting variables and contains two */
          /* columns _LHAND and _RHAND as outlined below.                                                                                       */
          /* *** Please read the following instructions carefully before including following script as part of your overall migration script*** */
           
          /* 1. If the individual trivial rules dataset are already created, then remove the following script. Running the script may lead to   */
          /* overwriting valid datasets. The start and the end of the script for these specific datasets is indicated below.                    */
          /* 2. The following script can be modified to create only the blank datasets.                                                         */
           /* ---------------------------------------------------------------------------------------------------------------------------------*/

            /* Creates the Parmsl.LABORCD_TRIVIALRULS and populates it    */
            /* Creates the Parmsl.REPLACEPRT_TRIVIALRULS and populates it */
            /* - for Failure Relation Ship analysis                       */
            /*   for  defect S0642857  requirment                         */  
            
            /* -------------------------------------------------------------- */
        create table &parmsllibref..LABORCD_TRIVIALRULS (label='Laborcode Trivial Rules',
        _LHAND                      char(13) label='_LHAND',
        _RHAND                      char(13) label='_RHAND')
         ;

        create table &parmsllibref..REPLACEPRT_TRIVIALRULS (label='Replace Parts Trivial Rules',
         _LHAND                      char(32) label='_LHAND',
         _RHAND                      char(32) label='_RHAND')
        ;
        
    
         
         /* -------------------------------------------------------------- */
         /* Creates the Parmsl.ANALYSISPDFTEMPLATE and populates it        */
         /*  for Export to PDF feature                                     */
         /*   for  defect S0692838  requirment                             */  
         /* -------------------------------------------------------------- */


                
                create table &parmsllibref..ANALYSISPDFTEMPLATE
                (compress=yes reuse=yes label='Analysis PDF Generation Template')
                (
                  ANALTYPE              char(32) label='Analysis Type',
                  ARTIFACT              char(32) label='Data Artifact Name',
                  ORDER                 numeric  label='Order of Appearance',
                  GENERATEFLAG          char(1)  label='Generate Missing Table',
                  TYPE                  char(1)  label='Template Entry Type'
                );
                
                
                
                insert into &parmsllibref..ANALYSISPDFTEMPLATE
                (ANALTYPE ,  ARTIFACT ,  ORDER ,  GENERATEFLAG  ,  TYPE   )
                Values ('CROSSTAB','Results',1,'0','2')
                Values ('CROSSTAB','variables',3,'1','0')
                Values ('CROSSTAB','summary',4,'0','0')
                Values ('CROSSTAB','detail',5,'0','0')
                Values ('CROSSTAB','Messages',6,'0','2')
                Values ('CROSSTAB','messages',7,'0','0')
                Values ('DETAIL','Results',1,'0','2')
                Values ('DETAIL','summarized',2,'0','0')
                Values ('DETAIL','Messages',3,'0','2')
                Values ('DETAIL','messages',4,'0','0')
                Values ('EIANALYTIC','Results',1,'0','2')
                Values ('EIANALYTIC','silk_viewg',2,'0','1')
                Values ('EIANALYTIC','datag',3,'0','0')
                Values ('EIANALYTIC','Messages',4,'0','2')
                Values ('EIANALYTIC','messages',5,'0','0')
                Values ('EIAUTOMATED','Results',1,'0','2')
                Values ('EIAUTOMATED','silk_viewg',2,'0','1')
                Values ('EIAUTOMATED','datag',3,'0','0')
                Values ('EIDRILLTO','Results',1,'0','2')
                Values ('EIDRILLTO','silk_viewg',2,'0','1')
                Values ('EIDRILLTO','datag',3,'1','0')
                Values ('EIDRILLTO','Messages',4,'0','2')
                Values ('EIDRILLTO','messages',5,'0','0')
                Values ('EIDRILLTOA','Results',1,'0','2')
                Values ('EIDRILLTOA','silk_viewg',2,'0','1')
                Values ('EIDRILLTOA','datag',3,'1','0')
                Values ('EIDRILLTOA','Messages',4,'0','2')
                Values ('EIDRILLTOA','messages',5,'0','0')
                Values ('EITHRESHOLD','Results',1,'0','2')
                Values ('EITHRESHOLD','silk_viewg',2,'0','1')
                Values ('EITHRESHOLD','summarized',3,'1','0')
                Values ('EITHRESHOLD','Messages',4,'0','2')
                Values ('EITHRESHOLD','messages',5,'0','0')
                Values ('THRESHOLD','Results',1,'0','2')
                Values ('THRESHOLD','silk_viewg',2,'0','1')
                Values ('THRESHOLD','summarized',3,'1','0')
                Values ('THRESHOLD','Messages',4,'0','2')
                Values ('THRESHOLD','messages',5,'0','0')
                Values ('EXPOSURE','Results',1,'0','2')
                Values ('EXPOSURE','silk_viewg',2,'0','1')
                Values ('EXPOSURE','summarized',3,'0','0')
                Values ('EXPOSURE','Messages',4,'0','2')
                Values ('EXPOSURE','messages',5,'0','0')
                Values ('FAILREL','Results',1,'0','2')
                Values ('FAILREL','silk_viewg',2,'0','1')
                Values ('FAILREL','summarized',3,'0','0')
                Values ('FAILREL','Rule Progression',4,'0','2')
                Values ('FAILREL','detail',5,'0','0')
                Values ('FAILREL','Messages',6,'0','2')
                Values ('FAILREL','messages',7,'0','0')
                Values ('FORECASTING','Results',1,'0','2')
                Values ('FORECASTING','silk_viewg',2,'0','1')
                Values ('FORECASTING','summarizedg',3,'1','0')
                Values ('FORECASTING','Messages',4,'0','2')
                Values ('FORECASTING','messages',5,'0','0')
                Values ('GEOGRAPHIC','Results',1,'0','2')
                Values ('GEOGRAPHIC','silk_viewg',2,'0','1')
                Values ('GEOGRAPHIC','silk_datag',3,'1','0')
                Values ('GEOGRAPHIC','Messages',4,'0','2')
                Values ('GEOGRAPHIC','messages',5,'0','0')
                Values ('MULTIVARIATE','Results',1,'0','2')
                Values ('MULTIVARIATE','importancelist',2,'1','0')
                Values ('MULTIVARIATE','barSilkView',3,'0','1')
                Values ('MULTIVARIATE','nodestatdsg',4,'1','0')
                Values ('MULTIVARIATE','pathds',5,'1','0')
                Values ('MULTIVARIATE','dtreeSilkView',6,'0','1')
                Values ('MULTIVARIATE','Summary',7,'0','2')
                Values ('MULTIVARIATE','datads',8,'0','0')
                Values ('MULTIVARIATE','Messages',9,'0','2')
                Values ('MULTIVARIATE','messages',10,'0','0')
                Values ('PARETO','Results',1,'0','2')
                Values ('PARETO','silk_view',2,'0','1')
                Values ('PARETO','summarized',3,'1','0')
                Values ('PARETO','Messages',4,'0','2')
                Values ('PARETO','messages',5,'0','0')
                Values ('RELIABILITY','Probability Plot',1,'0','2')
                Values ('RELIABILITY','summarizedg',2,'1','0')
                Values ('RELIABILITY','silk_viewg',3,'0','1')
                Values ('RELIABILITY','Distribution',4,'0','2')
                Values ('RELIABILITY','dist_summarized',5,'1','0')
                Values ('RELIABILITY','failprobdistview',6,'0','1')
                Values ('RELIABILITY','hazardview',7,'0','1')
                Values ('RELIABILITY','cmfaildistview',8,'0','1')
                Values ('RELIABILITY','Tables',9,'0','2')
                Values ('RELIABILITY','blife_summarized',10,'1','0')
                Values ('RELIABILITY','proj_summarized',11,'1','0')
                Values ('RELIABILITY','Messages',12,'0','2')
                Values ('RELIABILITY','message',13,'1','0')
                Values ('STATDRIVER','Results',1,'0','2')
                Values ('STATDRIVER','import_summarized',2,'1','0')
                Values ('STATDRIVER','scatter_view',3,'1','1')
                Values ('STATDRIVER','summarizedg',4,'1','0')
                Values ('STATDRIVER','Messages',5,'0','2')
                Values ('STATDRIVER','messages',6,'0','0')
                Values ('TEXTANALYSIS','Results',1,'0','2')
                Values ('TEXTANALYSIS','cluster_summarized',2,'0','0')
                Values ('TEXTANALYSIS','cluster',3,'0','1')
                Values ('TEXTANALYSIS','silk_view',4,'0','0')
                Values ('TEXTANALYSIS','summarized',5,'0','0')
                Values ('TEXTANALYSIS','Messages',6,'0','2')
                Values ('TEXTANALYSIS','messages',7,'0','0')
                Values ('TIMEOFCLAIM','Results',1,'0','2')
                Values ('TIMEOFCLAIM','silk_viewg',2,'0','1')
                Values ('TIMEOFCLAIM','summarizedg',3,'1','0')
                Values ('TIMEOFCLAIM','Messages',4,'0','2')
                Values ('TIMEOFCLAIM','messages',5,'0','0')
                Values ('TREND','Results',1,'0','2')
                Values ('TREND','silk_view',2,'0','1')
                Values ('TREND','summarizedg',3,'1','0')
                Values ('TREND','Control Plots',4,'0','2')
                Values ('TREND','control_view1',5,'0','1')
                Values ('TREND','Messages',6,'0','2')
                Values ('TREND','messages',7,'0','0')
                Values ('TRENDEXP','Results',1,'0','2')
                Values ('TRENDEXP','silk_viewg',2,'0','1')
                Values ('TRENDEXP','summarized',3,'0','0')
                Values ('TRENDEXP','Messages',4,'0','2')
                Values ('TRENDEXP','messages',5,'0','0')
                ;

         /* -----------------------------------------------------------------------*/
         /* Changes in Parmsl.anlformatlabel_format_nls                            */
         /*  for Fraction values in table become roundup in exported spread sheet  */
         /*   for  defect S0692836                                                 */  
         /* ---------------------------------------------------------------------- */   

                select key into :l_key
                from &parmslLibRef..anlformatlabel_base
                where upcase(VARNAME)='INDEX'
                ;

                %put l_key=&l_key;

                update &parmslLibRef..anlformatlabel_format_nls set 
                TEXT='NLNUM16.3'
                where key= "&l_key"  and LOCALE = "&locale" and LINENO = 1
                ;
                
                select VARIABLEID into :l_key
                           from &parmslLibRef..variables_base
                           where upcase(NAME)='COSTINDEX'
                ;
                
                update &parmslLibRef..variables_format_nls set 
                TEXT='NLNUM16.3'
                where key= "&l_key"  and LOCALE = "&locale" and LINENO = 1
                ;

         /* -----------------------------------------------------------------------*/
         /* Changes in Parmsl.modulesdefinition                                                */
         /*   for  defect S0699347                                                                 */  
         /* ---------------------------------------------------------------------- */   

                
                insert into &parmslLibRef..MODULESDEFINITION
                (MODULENAME,MODULECONTROLLER)
                values ('UTIL_DELETEPROJECT','%util_deleteproject')
                ;
                
         /* -----------------------------------------------------------------------*/
         /* Create Parmsl.JobFinishedCounts                                          */
         /* ---------------------------------------------------------------------- */   

            create table &parmslLibRef..JOBFINISHEDCOUNTS (label='Job Finished Counts') (
            USERID                      char(64) label='User ID',
            YEAR                        numeric label='Year',
            DAYOFYEAR                   numeric label='Day Of Year',
            BATCHJOBCOUNT1              numeric,
            BATCHJOBCOUNT2              numeric,
            BATCHJOBCOUNT3              numeric,
            BATCHJOBCOUNT4              numeric,
            BATCHJOBCOUNT5              numeric,
            BATCHJOBCOUNT6              numeric,
            BATCHJOBCOUNT7              numeric,
            BATCHJOBCOUNT8              numeric,
            BATCHJOBCOUNT9              numeric,
            BATCHJOBCOUNT10             numeric,
            BATCHJOBCOUNT11             numeric,
            BATCHJOBCOUNT12             numeric,
            BATCHJOBCOUNT13             numeric,
            BATCHJOBCOUNT14             numeric,
            BATCHJOBCOUNT15             numeric,
            BATCHJOBCOUNT16             numeric,
            BATCHJOBCOUNT17             numeric,
            BATCHJOBCOUNT18             numeric,
            BATCHJOBCOUNT19             numeric,
            BATCHJOBCOUNT20             numeric,
            BATCHJOBCOUNT21             numeric,
            BATCHJOBCOUNT22             numeric,
            BATCHJOBCOUNT23             numeric,
            BATCHJOBCOUNT24             numeric,
            INTERACTIVEJOBCOUNT1        numeric,
            INTERACTIVEJOBCOUNT2        numeric,
            INTERACTIVEJOBCOUNT3        numeric,
            INTERACTIVEJOBCOUNT4        numeric,
            INTERACTIVEJOBCOUNT5        numeric,
            INTERACTIVEJOBCOUNT6        numeric,
            INTERACTIVEJOBCOUNT7        numeric,
            INTERACTIVEJOBCOUNT8        numeric,
            INTERACTIVEJOBCOUNT9        numeric,
            INTERACTIVEJOBCOUNT10       numeric,
            INTERACTIVEJOBCOUNT11       numeric,
            INTERACTIVEJOBCOUNT12       numeric,
            INTERACTIVEJOBCOUNT13       numeric,
            INTERACTIVEJOBCOUNT14       numeric,
            INTERACTIVEJOBCOUNT15       numeric,
            INTERACTIVEJOBCOUNT16       numeric,
            INTERACTIVEJOBCOUNT17       numeric,
            INTERACTIVEJOBCOUNT18       numeric,
            INTERACTIVEJOBCOUNT19       numeric,
            INTERACTIVEJOBCOUNT20       numeric,
            INTERACTIVEJOBCOUNT21       numeric,
            INTERACTIVEJOBCOUNT22       numeric,
            INTERACTIVEJOBCOUNT23       numeric,
            INTERACTIVEJOBCOUNT24       numeric
            /* A primary key is NOT desirable for this table. USERID, YEAR, DAYOFYEAR and HOUROFDAY 
                 would be a compound key if there has to be an index. */
            );
            
          /* -----------------------------------------------------------------------------------*/
	  /*To take care of Exception when editing Claim cost parameter on EI-analytic S0716499 */
          /* ---------------------------------------------------------------------------------- */   


  		update &parmslLibRef..Analysisoptionattributes_base
  		set FORMATREGEX="[^,]*"
  		where upcase(NAME) in ('USERTITLE'
		'USERSUBTITLE' 'USERFOOTNOTE' 'DEFINEDHIERARCHYWHERE' 'PRODUCTWHERE'
		'PRODUCTWHEREDISPLAY'  'CLAIMSWHERE' 'CLAIMSWHEREDISPLAY' 'EICOSTVARS')
		 ;
